(function (root, factory) {
	if ( typeof define === 'function' && define.amd ) {
		define([], factory(root));
	} else if ( typeof exports === 'object' ) {
		module.exports = factory(root);
	} else {
		root.slidingWidgetopts = factory(root);
	}
})(typeof global !== "undefined" ? global : this.window || this.global, function (root) {

	'use strict';

	//
	// Variables
	//

	var slidingWidgetopts = {}; // Object for public APIs
	var supports = !!document.querySelector && !!root.addEventListener; // Feature test
	var settings, eventTimeout;

	// Default settings
	var defaults = {
		initClass: 'js-sldwdgtopts',
		gutter: 15,
		responsive: 900,
		mobile: 767,
		cachedWidth: window.innerWidth || document.documentElement.clientWidth || document.body.clientWidth,
		callbackBefore: function () {},
		callbackAfter: function () {}
	};


	//
	// Methods
	//

	/**
	 * A simple forEach() implementation for Arrays, Objects and NodeLists
	 * @private
	 * @param {Array|Object|NodeList} collection Collection of items to iterate
	 * @param {Function} callback Callback function for each iteration
	 * @param {Array|Object|NodeList} scope Object/NodeList/Array that forEach is iterating over (aka `this`)
	 */
	var forEach = function (collection, callback, scope) {
		if (Object.prototype.toString.call(collection) === '[object Object]') {
			for (var prop in collection) {
				if (Object.prototype.hasOwnProperty.call(collection, prop)) {
					callback.call(scope, collection[prop], prop, collection);
				}
			}
		} else {
			for (var i = 0, len = collection.length; i < len; i++) {
				callback.call(scope, collection[i], i, collection);
			}
		}
	};

	/**
	 * Merge defaults with user options
	 * @private
	 * @param {Object} defaults Default settings
	 * @param {Object} options User options
	 * @returns {Object} Merged values of defaults and options
	 */
	var extend = function ( defaults, options ) {
		var extended = {};
		forEach(defaults, function (value, prop) {
			extended[prop] = defaults[prop];
		});
		forEach(options, function (value, prop) {
			extended[prop] = options[prop];
		});
		return extended;
	};

	/**
	 * Convert data-options attribute into an object of key/value pairs
	 * @private
	 * @param {String} options Link-specific options as a data attribute string
	 * @returns {Object}
	 */
	var getDataOptions = function ( options ) {
		return !options || !(typeof JSON === 'object' && typeof JSON.parse === 'function') ? {} : JSON.parse( options );
	};

	//get parentNode with specific class
	function findAncestor (el, cls) {
		while ((el = el.parentElement) && !el.classList.contains(cls));
		return el;
	}

	//check if Child
	function isAChildOf( _parent, _child ){
	   if ( _parent === _child ) { return false; }
	      while ( _child && _child !== _parent ){
			  _child = _child.parentNode;
		  }
	   return _child === _parent;
	}

	//close
	function closeIt( widget, position, placement ){
		var wrappr 	= findAncestor( widget, 'sl-widgetopts-wrp' );

        widget.style[placement] = '0px';
        widget.classList.remove( 'sl-widgetopts-on' );

		setTimeout(
	    function () {
	       wrappr.style.zIndex = '';
	   }, 380);

	}

	function closeModal(){
		var slfooter = document.getElementById( 'sl-widgetopts-footer' );
		slfooter.classList.remove( 'sl-widgetopts-modalon' );
		slfooter.style.top = '-500px';
		slfooter.style.opacity = '0';
		document.getElementById( 'sl-widgetopts-overlay' ).style.display = 'none';
		setTimeout(
	    function () {
	       slfooter.style.display = 'none';
	   }, 300);
	}

	function closeSlide( widget, position, direction ){
		if( widget === undefined ){
			widget = document.querySelector( '.sl-widgetopts-slideon' );
			// console.log( widget );
			if( typeof(widget) != 'undefined' && widget !== null ){
				direction = widget.getAttribute( 'data-direction' );
			}
		}

		if( typeof(widget) != 'undefined' && widget !== null  ){
			widget.querySelector( '.sl-widgetopts-w-in' ).style[direction] = -( widget.querySelector( '.sl-widgetopts-w-in' ).clientWidth ) + 'px';
			widget.classList.remove( 'sl-widgetopts-slideon' );
		}
	}

	function perType( type, el, pos, maxH ){
		switch ( type ) {
			case 'modal':
				var dw = el.querySelector('.sliding-widgetopts').getAttribute( 'data-width' );
				if( parseInt( dw ) < 10 ){
					dw = 500;
				}

				document.getElementById( 'sl-widgetopts-footer' ).style[ 'width' ] = dw + 'px';

				//add unique class
				if( el.querySelector('.widget') !== null ){
					el.querySelector('.widget').classList.add( 'widgetops-mdal-' + el.querySelector('.sliding-widgetopts').getAttribute( 'data-widgetid' ) )

					document.getElementById( 'sl-widgetopts-footer-in' ).innerHTML += el.querySelector('.widget').outerHTML;

					//auto open gravity form on submission error
					if( el.querySelector('.widget').classList.contains( 'widgetopts-gravity-fix' ) ){
						if( el.querySelectorAll('.gform_validation_error').length > 0 || el.querySelectorAll('.gform_confirmation_wrapper').length > 0 ){
							el.querySelector( '.sl-widgetopts-lbl' ).click();
						}
					}
					el.querySelector('.widget').outerHTML = '';
				}
				break;
			case 'slide':
				if( pos == 'left' || pos == 'right' ){
					if( is_mobile() ){
						el.querySelector( '.widget' ).style.minHeight = el.querySelector( '.sl-widgetopts-lbl' ).clientWidth + parseInt( el.querySelector( '.sl-widgetopts-lbl' ).style.top ) + 'px';
					}else{
						el.querySelector( '.widget' ).style.minHeight = el.querySelector( '.sl-widgetopts-lbl' ).clientWidth + 21 + 'px';
					}
					el.querySelector( '.widget' ).style.maxHeight = ( maxH - 30 ) + 'px';
				}else{
					// var maxH = window.innerHeight || document.documentElement.clientHeight || document.body.clientHeight;
					el.querySelector( '.widget' ).style.maxHeight = ( maxH - 100 ) + 'px';

					//fix ajax submission
					if( el.querySelector( '.widget' ).classList.contains( 'widgetopts-ajax-fix' ) ){
						el.querySelector( '.widget' ).style.height = el.querySelector( '.widget' ).clientHeight + 'px';
					}

					var hh = el.querySelector('.sliding-widgetopts').clientHeight;
					if( is_mobile() ){
						if( hh > (maxH - 100) ){
							hh = maxH - 100;
						}

						el.style[ 'margin-bottom' ]  = -hh + 'px';
					}
				}

				//add width
				// el.style[ 'width' ] = dw + 'px';
				// console.log( dw );
				break;
			// case 'slidein':
			// 		el.querySelector( '.widget' ).style.width = el.querySelector('.sliding-widgetopts').getAttribute( 'data-width' );
			// 	break;
			default:

		}
		el.style['opacity'] = 1;
	}

	function is_responsive() {
		var docwidth 	= document.body.clientWidth;

		if( docwidth <= defaults.responsive ){
			document.body.classList.add( 'sl-widgetopts-responsive' );
			return true;
		}
		return false;
	};

	function is_mobile() {
		var docwidth 	= document.body.clientWidth;

		if( docwidth <= defaults.mobile ){
			return true;
		}
		return false;
	};

	//mouse movements
	function mouseEnter( _fn ){
	   return function( _evt ){
	      var relTarget = _evt.relatedTarget;
	      if ( this === relTarget || isAChildOf( this, relTarget ) )
	         { return; }

	      _fn.call( this, _evt );
	   }
	};

	//handle cookies
	function createCookie( n, v, d ){
	    var expires = "";
	    if (d) {
	        var date = new Date();
	        date.setTime(date.getTime() + (d*24*60*60*1000));
	        expires = "; expires=" + date.toUTCString();
	    }
	    document.cookie = n + "=" + v + expires + "; path=/";
	}

	function readCookie( n ) {
	    var nameEQ = n + "=";
	    var ca = document.cookie.split(';');
	    for(var i=0;i < ca.length;i++) {
	        var c = ca[i];
	        while (c.charAt(0)==' ') c = c.substring(1,c.length);
	        if (c.indexOf(nameEQ) == 0) return c.substring(nameEQ.length,c.length);
	    }
	    return null;
	}


	/**
	 * Handle onLoad event
	 * @private
	 */
	var loadHandler = function (event) {
		var enteron 	= document.querySelectorAll( '.sl-widgetopts-enter' );
		var btmrght 	= document.querySelectorAll( '.sl-widgetopts-bottom-right' );
		var btmlft 		= document.querySelectorAll( '.sl-widgetopts-bottom-left' );
		var tplft 		= document.querySelectorAll( '.sl-widgetopts-top-left' );
		var tprght 		= document.querySelectorAll( '.sl-widgetopts-top-right' );
		var slidein 	= document.querySelectorAll( '.sl-widgetopts-slidein' );
		var footerin 	= document.getElementById( 'sl-widgetopts-footer-in' );
		var maxH 		= window.innerHeight || document.documentElement.clientHeight || document.body.clientHeight;
		var maxW 		= window.innerWidth || document.documentElement.clientWidth || document.body.clientWidth;

		//add responsive class

		// console.log( maxW );

    		if( btmrght.length > 0 ){
					var btmright = 50;
					var cntb   	 = 0;
					// if( is_mobile() ){
					// 	// btmright = 20;
					// }
        			Array.from( btmrght ).forEach(function( r, i ){
						var dw = r.querySelector('.sliding-widgetopts').getAttribute( 'data-width' );
						var gt = r.querySelector('.sliding-widgetopts').getAttribute( 'data-sltype' );

						if( parseInt( dw ) < 10 ){
							dw = 350;
						}

						if( gt == 'slide' ){
							r.style[ 'width' ] 		= dw + 'px';
						}else{
							r.style[ 'width' ] 		= 'auto';
							r.classList.add( 'sl-widgetopts-mw' );
						}

						if( r.querySelector( '.sl-widgetopts-lbl' ).clientHeight > 1 ){
							if( cntb > 0 ){
								if( is_responsive() ){
									btmright += btmrght[ i-1 ].querySelector( '.sl-widgetopts-lbl' ).clientWidth;
								}else{
									btmright += btmrght[ i-1 ].clientWidth;
								}
	        				}
							btmright += defaults.gutter;
							cntb++;
						}

						r.style.right = btmright + 'px';
						// console.log( r.style.right );

						if( is_mobile() ){
							if( i < 1 ){
								btmright = btmright - defaults.gutter;
							}
							r.querySelector( '.sl-widgetopts-lbl' ).style.right = ( btmright - 45 ) + 'px';
							// r.querySelector( '.sliding-widgetopts' ).style[ 'top' ] 	= 'auto';
						}else{
							r.querySelector( '.sl-widgetopts-lbl' ).style.right = 'auto';
						}

						perType( r.querySelector('.sliding-widgetopts').getAttribute( 'data-sltype' ), r , 'bottom', maxH  );
        	    });
    		}
            if( btmlft.length > 0 ){
				var btmleft = 50;
				var cntbl   = 0;
        			Array.from( btmlft ).forEach(function( l, x ){

						var dwl = l.querySelector('.sliding-widgetopts').getAttribute( 'data-width' );
						var gtl = l.querySelector('.sliding-widgetopts').getAttribute( 'data-sltype' );

						if( parseInt( dwl ) < 10 ){
							dwl = 350;
						}

						if( gtl == 'slide' ){
							l.style[ 'width' ] 		= dwl + 'px';
						}else{
							l.style[ 'width' ] 		= 'auto';
							l.style[ 'minWidth' ] 	= 'auto';
						}

						if( l.querySelector( '.sl-widgetopts-lbl' ).clientHeight > 1 ){
							if( cntbl > 0 ){
								if( is_responsive() ){
									btmleft += btmlft[ x-1 ].querySelector( '.sl-widgetopts-lbl' ).clientWidth;
								}else{
									btmleft += btmlft[ x-1 ].clientWidth;
								}
	        				}
							btmleft += defaults.gutter;
							cntbl++;
						}

						l.style.left = btmleft + 'px';

						if( is_mobile() ){
							if( x < 1 ){
								btmleft = btmleft - defaults.gutter;
							}
							l.querySelector( '.sl-widgetopts-lbl' ).style.left = ( btmleft - 45 ) + 'px';
						}else{
							l.querySelector( '.sl-widgetopts-lbl' ).style.left = 'auto';
						}

						perType( l.querySelector('.sliding-widgetopts').getAttribute( 'data-sltype' ), l, 'bottom', maxH  );
        	    });
            }
			if( tplft.length > 0 ){
				var toplft = parseInt( sliding_widgetopts.top );
				var mHL	   = 1000;
				var cntl   = 0;
				if( is_mobile() ){
					toplft = parseInt( sliding_widgetopts.mobile );
				}
        			Array.from( tplft ).forEach(function( a, y ){

						var dwt = a.querySelector('.sliding-widgetopts').getAttribute( 'data-width' );

						if( parseInt( dwt ) < 300 ){
							dwt = 300;
						}

						a.style[ 'width' ] = dwt + 'px';
						a.querySelector('.sliding-widgetopts').style[ 'width' ] = dwt + 'px';
						// console.log( a.clientWidth );

						a.querySelector( '.sl-widgetopts-lbl' ).style.left = ( a.clientWidth + 21 ) + 'px';

						//add height condition for empty/hidden labels
						if( a.querySelector( '.sl-widgetopts-lbl' ).clientHeight > 1 ){
							if( cntl > 0 ){
								toplft += tplft[ y-1 ].querySelector( '.sl-widgetopts-lbl' ).clientWidth;
							}
							toplft += defaults.gutter;
							cntl++;
						}

						if( is_mobile() ){
							a.style.top = '0px';
						}else{
							a.style.top = toplft + 'px';
						}

						mHL 		= maxH - toplft;

						if( is_mobile() ){
							var dtl = toplft + ( a.querySelector( '.sl-widgetopts-lbl' ).clientWidth * .5 ) - 42 + 'px';
							a.querySelector( '.sl-widgetopts-lbl' ).style.top = dtl;
							mHL = maxH + 30;
						}else{
							a.querySelector( '.sl-widgetopts-lbl' ).style.top = ( (a.querySelector( '.sl-widgetopts-lbl' ).clientWidth ) * .5 ) + 'px';
						}


						perType ( a.querySelector('.sliding-widgetopts').getAttribute( 'data-sltype' ), a, 'left', mHL  );
        	    });
            }
			if( tprght.length > 0 ){
				var toprght = parseInt( sliding_widgetopts.top );
				var mHR	   = 1000;
				var cntr   = 0;
				if( is_mobile() ){
					toprght = parseInt( sliding_widgetopts.mobile );
				}
        		Array.from( tprght ).forEach(function( m, n ){

					var dwr = m.querySelector('.sliding-widgetopts').getAttribute( 'data-width' );

					if( parseInt( dwr ) < 300 ){
						dwr = 300;
					}

					m.style[ 'width' ] = dwr + 'px';
					m.querySelector('.sliding-widgetopts').style[ 'width' ] = dwr + 'px';

					m.querySelector( '.sl-widgetopts-lbl' ).style.right = ( m.clientWidth + 21 ) + 'px';

					if( m.querySelector( '.sl-widgetopts-lbl' ).clientHeight > 1 ){
						if( cntr > 0 ){
							toprght += tprght[ n-1 ].querySelector( '.sl-widgetopts-lbl' ).clientWidth;
						}
						toprght += defaults.gutter;
						cntr++;
					}
					if( is_mobile() ){
						m.style.top = '0px';
					}else{
						m.style.top = toprght + 'px';
					}
					mHR 		= maxH - toprght;

					if( is_mobile() ){
						var dt = toprght + ( m.querySelector( '.sl-widgetopts-lbl' ).clientWidth * .5 ) - 42 + 'px';
						m.querySelector( '.sl-widgetopts-lbl' ).style.top = dt;
						mHR = maxH + 30;
					}else{
						m.querySelector( '.sl-widgetopts-lbl' ).style.top = ( m.querySelector( '.sl-widgetopts-lbl' ).clientWidth * .5 ) - 42 + 'px';
					}
					perType ( m.querySelector('.sliding-widgetopts').getAttribute( 'data-sltype' ), m, 'right', mHR  );
        	    });
            }

			// console.log( slidein );
			if( slidein.length > 0 ){
					var dr = '';
					var dw = 0;
        			Array.from( slidein ).forEach(function( c, d ){
						dr = c.querySelector( '.sliding-widgetopts' ).getAttribute( 'data-direction' );

						dw = c.querySelector( '.sliding-widgetopts' ).getAttribute( 'data-width' );
						if( parseInt( dw ) < 10 ){
							dw = 500;
						}

						c.querySelector( '.sl-widgetopts-w-in' ).style[ dr ] = -(c.querySelector( '.sl-widgetopts-w-in' ).clientWidth) + 'px';
						c.querySelector( '.sl-widgetopts-w-in' ).style[ 'max-width' ] =  dw + 'px';
						c.querySelector( '.sl-widgetopts-w-in' ).style[ 'max-height' ] = ( maxH * .82 ) + 'px';
						c.querySelector( '.widget' ).style[ 'height' ] = ( c.querySelector( '.sl-widgetopts-w-in' ).clientHeight ) + 'px';
	        			c.querySelector( '.sl-widgetopts-w-in' ).innerHTML += '<span class="sl-widgetopts-slideoff sl-widgetopts-slidex"><a href="#" onclick="return false;" class="sl-widgetopts-slideoff"><span class="sl-widgetopts-slideoff dashicons dashicons-no-alt"></span></a></span>';
        	    	});
    		}

			//entrance
			if( enteron.length > 0 ){
				var lst 		= enteron[ enteron.length - 1 ];
				var widgetid 	= lst.querySelector('.sliding-widgetopts').getAttribute( 'data-widgetid' );
				var trigger 	= lst.querySelector('.sliding-widgetopts').getAttribute( 'data-trigger' );
				var nC 			= 'sl-widgetopts_' + widgetid;
				if( trigger !== null && 'once' == trigger ){
					var rCookie 	= readCookie( nC );
				}

				// console.log( rCookie );
				if( !lst.classList.contains( 'sl-widgetopts-entered' ) ){
					if( ( rCookie === null && 'once' == trigger ) || ( typeof rCookie === 'undefined' && 'always' == trigger ) ){
						lst.querySelector( '.sl-widgetopts-lbl' ).click();
						lst.classList.add( 'sl-widgetopts-entered' );
						if( trigger !== null && 'once' == trigger ){
							createCookie( nC, '1', 200 );
						}
					}
				}
			}

			if( typeof footerin !== "undefined" && typeof footerin !== null && footerin !== null ){
				footerin.style[ 'maxHeight' ] = ( maxH * .80 ) + 'px';
			}

			//create custom event
			var evt = document.createEvent( 'Event' );
			evt.initEvent( 'Sliding_Widgets_Loaded', true, true );
			document.dispatchEvent(evt);

	};

	/**
	 * Handle events
	 * @private
	 */
	var eventHandler = function (event) {
		var el = event.target;
		if( el.classList.contains( 'sl-widgetopts-o' ) ){
			//prevent scrolling
			event.returnValue = false;

			//get parentNode
			var wrapper 	= findAncestor( el, 'sl-widgetopts-wrp' );
			var inner 		= wrapper.querySelector( '.sliding-widgetopts' );

			//close all open
			var wrapperon 	= document.querySelectorAll( '.sl-widgetopts-on' );
			// console.log( wrapperon );
			if( wrapperon.length > 0 ){
				Array.from( wrapperon ).forEach(function( a, b ){
					if( a != inner ){
						closeIt( a, a.getAttribute( 'data-position' ), a.getAttribute( 'data-placement' ) );
					}
				});
			}

			//add styling
			if( el.getAttribute( 'data-color' ) !== null && el.getAttribute( 'data-color' ).length > 0 ){
				el.style.color = el.getAttribute( 'data-color' );
				// console.log( el.getAttribute( 'data-color' ).length );
			}
			if( el.getAttribute( 'data-bg' ) !== null && el.getAttribute( 'data-bg' ).length > 0 ){
				el.style.background = el.getAttribute( 'data-bg' );
			}
			// console.log( el.getAttribute( 'data-color' ).length );


			var widget 		= wrapper.querySelector( '.widget' );
			var position 	= inner.getAttribute( 'data-position' );
			var placement 	= inner.getAttribute( 'data-placement' );
			var type 		= inner.getAttribute( 'data-sltype' );
			var clientparam = ( inner.clientHeight - 42 ) + 'px';

			if( is_mobile() ){
				clientparam = ( inner.clientHeight ) + 'px';
			}

			switch ( type ) {
				case 'slide':
					if( placement == 'left' || placement == 'right' ){
						 clientparam = inner.clientWidth + 'px';
					}

					closeSlide();

					if( inner.classList.contains( 'sl-widgetopts-on' ) ){
						closeIt( inner, position, placement );
					}else{
						wrapper.style.zIndex = 9999;
						inner.style[ placement ] = clientparam;
						inner.classList.add( 'sl-widgetopts-on' );
					}
					break;
				case 'modal':
					var slfooter = document.getElementById( 'sl-widgetopts-footer' );
					var dw = inner.getAttribute( 'data-width' );
					if( parseInt( dw ) < 10 ){
						dw = 500;
					}

					slfooter.style[ 'width' ] = dw + 'px';

					//Add all except selected
					Array.from( slfooter.querySelectorAll( '.widget' ) )
					    .forEach(function(val) {
							if( val.classList.contains( 'widgetops-mdal-' + inner.getAttribute( 'data-widgetid' ) ) ){
								val.style.display = 'block';
							}else{
								val.style.display = 'none';
							}
					});

					// console.log( 'a' );

					closeSlide();

					if( slfooter.classList.contains( 'sl-widgetopts-modalon' ) ){
						closeModal();
					}else{
						inner.querySelector('.sl-widgetopts-lbl').classList.add( 'sl-widgetopts-m-on' );
						slfooter.classList.add( 'sl-widgetopts-modalon' );
						slfooter.style.opacity = '1';
						slfooter.style.display = 'block';
						setTimeout(
					    function () {
					      	if( is_mobile() ){
								slfooter.style.top = '50px';
							}else{
								slfooter.style.top = '100px';
							}
							document.getElementById( 'sl-widgetopts-overlay' ).style.display = 'block';
					    }, 5);
					}
					break;
				case 'slidein':
					var direction 	= inner.getAttribute( 'data-direction' );
					if( inner.classList.contains( 'sl-widgetopts-slideon' ) ){
						closeSlide( inner, position, direction );
					}else{
						closeSlide();
						inner.classList.add( 'sl-widgetopts-slideon' );
					}
					break;

				default:

			}

			event.preventDefault();
			return false;
		}else if( el.classList.contains( 'sl-widgetopts-modaloff' ) ){
			closeModal();
			event.preventDefault();
		}else if( el.classList.contains( 'sl-widgetopts-slideoff' ) ){
			closeSlide();
			event.preventDefault();
		}else if( el.classList.contains( 'sl-widgetopts-open' ) ){
			//open using any element by adding class sl-widgetopts-open and data-taget
			var trget = el.getAttribute( 'href' );
			if( typeof trget != 'undefined' ){
				trget = trget.replace( '#', '.slwidgetopts-');
				document.querySelector( trget + ' .sl-widgetopts-lbl' ).click();
				event.preventDefault();
			}
		}else if( el.classList.contains( 'elementor-button-text' ) ){
			//open using any element by adding class sl-widgetopts-open and data-taget
			var btn_el = findAncestor( el, 'elementor-button' );
			if( typeof btn_el != 'undefined' ){
				var trget = btn_el.getAttribute( 'href' );
				if( typeof trget != 'undefined' ){
					trget = trget.replace( '#', '.slwidgetopts-');
					document.querySelector( trget + ' .sl-widgetopts-lbl' ).click();
					event.preventDefault();
				}
			}
		}
	};

	/**
	 * Destroy the current initialization.
	 * @public
	 */
	slidingWidgetopts.destroy = function () {

		// If plugin isn't already initialized, stop
		if ( !settings ) return;

		// Remove init class for conditional CSS
		document.documentElement.classList.remove( settings.initClass );

		// @todo Undo any other init functions...

		// Remove event listeners
		document.removeEventListener('click', eventHandler, false);

		// Reset variables
		settings = null;
		eventTimeout = null;

	};

	var scrollHandler = function( event ){
		var doc = document.documentElement;
		var b 	= document.body,
			st 	= 'scrollTop',
        	sh 	= 'scrollHeight';
		var top = (window.pageYOffset || doc.scrollTop)  - (doc.clientTop || 0);
		var percent = (doc[st]||b[st]) / ((doc[sh]||b[sh]) - doc.clientHeight) * 100;

		var scrollon 	= document.querySelectorAll( '.sl-widgetopts-scroll' );
		if( scrollon.length > 0 ){
			var prcnt = 0;
			var type = '';
			var widgetid = '';
			var trigger = '';
			var nC = '';
			var clck = false;
			Array.from( scrollon ).forEach(function( e, f ){
				clck  = false;
				prcnt = e.getAttribute( 'data-scroll' );
				type  = e.getAttribute( 'data-sctype' );

				widgetid 	= e.getAttribute( 'data-widgetid' );
				trigger 	= e.getAttribute( 'data-trigger' );
				nC 			= 'sl-widgetopts_' + widgetid;

				if( trigger !== null && 'once' == trigger ){
					var rCookie 	= readCookie( nC );
				}
				if( !e.classList.contains( 'sl-widgetopts-scrolled' ) ){
					switch ( type ) {
						case 'percent':
							if( percent >= prcnt  ){
								clck = true;
							}
							break;
						case 'px':
							if( top >= prcnt  ){
								clck = true;
							}
							break;
						default:

					}

					if( clck ){
						if( ( rCookie === null && 'once' == trigger ) || ( typeof rCookie === 'undefined' && 'always' == trigger ) ){
							e.querySelector( '.sl-widgetopts-lbl' ).click();
							closeModal();
							e.classList.add( 'sl-widgetopts-scrolled' );
							if( trigger !== null && 'once' == trigger ){
								createCookie( nC, '1', 200 );
							}
						}
					}


				}
			});
		}
	};

	var exitHandler = function( event ){
		var el 		= event.target;
		var exiton 	= document.querySelectorAll( '.sl-widgetopts-exit' );
		if( exiton.length > 0 ){
			if( event.clientY < 7 || event.clientX < 0 || event.clientX > window.innerWidth ){
				var last = exiton[ exiton.length - 1 ];
				var widgetid 	= last.querySelector('.sliding-widgetopts').getAttribute( 'data-widgetid' );
				var trigger 	= last.querySelector('.sliding-widgetopts').getAttribute( 'data-trigger' );
				var nC 			= 'sl-widgetopts_x_' + widgetid;
				if( trigger !== null && 'once' == trigger ){
					var rCookie 	= readCookie( nC );
				}
				// console.log( rCookie );
				if( !last.classList.contains( 'sl-widgetopts-exited' ) ){
					if( ( rCookie === null && 'once' == trigger ) || ( typeof rCookie === 'undefined' && 'always' == trigger ) ){
						last.querySelector( '.sl-widgetopts-lbl' ).click();
						last.classList.add( 'sl-widgetopts-exited' );
						if( trigger !== null && 'once' == trigger ){
							createCookie( nC, '1', 200 );
						}
					}
				}
			}
		}

	};

	function hoverHandler( event ){
		var el 		= event.target;
		var p = findAncestor( el, 'sliding-widgetopts' );
		if( !p.classList.contains( 'sl-widgetopts-on' ) ){
			el.click();
		}
	}

	function outHandler( event ){
		var el 	= event.target;
		var p   = findAncestor( el, 'sliding-widgetopts' );
		// console.log( p );
		if( p.classList.contains( 'sl-widgetopts-on' ) ){
			setTimeout( function(){
				closeIt( p, p.getAttribute( 'data-position' ), p.getAttribute( 'data-placement' ) );
				// .click();
			} ,150);

		}
	}

	var resizeHandler = function( event ){
		var gw = window.innerWidth || document.documentElement.clientWidth || document.body.clientWidth;
		if( gw != defaults.cachedWidth ){
			slidingWidgetopts.init();
			loadHandler();

			defaults.cachedWidth = gw;
			// console.log( gw );
		}

	};

	/**
	 * On window scroll and resize, only run events at a rate for better performance
	 * @private
	 * @param  {Function} eventTimeout Timeout function
	 * @param  {Object} settings
	 */
	var throttle = function(func, wait) {
		// we need to save these in the closure
		var timeout, args, context, timestamp;

		// this is where the magic happens
		var later = function() {

			// how long ago was the last call
			var last = Date.now() - timestamp;

			// if the latest call was less that the wait period ago
			// then we reset the timeout to wait for the difference
			if (last < wait) {
				timeout = setTimeout(later, wait - last);

			// or if not we can null out the timer and run the latest
			} else {
				timeout = null;
				func.apply(context, args);
			}
		};

		return function() {

			// save details of latest call
			context = this;
			args = arguments;
			timestamp = Date.now();

			// we only need to set the timer now if one isn't already running
			if (!timeout) {
				timeout = setTimeout(later, wait);
			}
		}
	}

	/**
	 * Initialize Plugin
	 * @public
	 * @param {Object} options User settings
	 */
	slidingWidgetopts.init = function ( options ) {

		// feature test
		if ( !supports ) return;

		// Destroy any existing initializations
		slidingWidgetopts.destroy();

		// Merge user options with defaults
		settings = extend( defaults, options || {} );

		// Add class to HTML element to activate conditional CSS
		document.documentElement.classList.add( settings.initClass );

		var scrollon 	= document.querySelectorAll( '.sl-widgetopts-scroll' );
		// Listen for events
		document.addEventListener( 'DOMContentLoaded', loadHandler, false );
		if( scrollon.length > 0 ){
			document.addEventListener( 'scroll', throttle( scrollHandler, 50 ), false );
		}
		document.addEventListener( 'click', eventHandler, false );
		document.addEventListener( 'touchend', eventHandler, false );
		// document.addEventListener( 'mouseleave', exitHandler, false );
		document.addEventListener( 'mouseout', exitHandler, false );
		// document.addEventListener( 'mouseover', hoverHandler, false );

		var mo = document.getElementsByClassName( 'sl-widgetopts-w-mo' );
		if( mo.length > 0 ){
			for( var i=0; i<mo.length; i++){
				mo[i].addEventListener( 'mouseover', mouseEnter( hoverHandler ), false );
				mo[i].addEventListener( 'mouseout', mouseEnter( outHandler ), false );
			}
		}

		//resize
		window.addEventListener( 'resize', throttle( resizeHandler, 50 ), false );

	};


	//
	// Public APIs
	//

	return slidingWidgetopts;

});
slidingWidgetopts.init();
