<?php
/**
 * Scripts
 *
 * @copyright   Copyright (c) 2017, Jeffrey Carandang
 * @since       1.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Load Scripts
 *
 * Enqueues the required scripts.
 *
 * @since 1.0
 * @global $widget_options
 * @return void
 */
if( !function_exists( 'widgetopts_slidein_load_scripts' ) ):
    function widgetopts_slidein_load_scripts(){
        global $widget_options, $pagenow;

        $js_dir  = SLIDING_WIDGETOPTS_PLUGIN_URL . 'assets/js/';
        $css_dir = SLIDING_WIDGETOPTS_PLUGIN_URL . 'assets/css/';

        // Use minified libraries if SCRIPT_DEBUG is turned off
        $suffix  = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '.min';

        wp_register_style( 'sliding-widgetopts-styles', $css_dir . 'sliding-widgetopts.css' , array( 'dashicons' ), null );

        // wp_enqueue_style( 'wp-color-picker' );
        // wp_enqueue_script('wp-color-picker');

        wp_enqueue_script(
            'sliding-widgetopts-scripts',
            $js_dir .'sliding-widgetopts'. $suffix .'.js',
            array( 'jquery' ),
            '',
            true
        );

        wp_localize_script( 'sliding-widgetopts-scripts', 'sliding_widgetopts', array(
            'top'       => ( ( isset( $widget_options['settings'] ) && isset( $widget_options['settings']['sliding'] ) && isset( $widget_options['settings']['sliding']['top'] ) && !empty( $widget_options['settings']['sliding']['top'] ) ) ? $widget_options['settings']['sliding']['top'] : 100 ),
            'mobile'    => ( ( isset( $widget_options['settings'] ) && isset( $widget_options['settings']['sliding'] ) && isset( $widget_options['settings']['sliding']['top_mobile'] ) && !empty( $widget_options['settings']['sliding']['top_mobile'] ) ) ? $widget_options['settings']['sliding']['top_mobile'] : 100 )
        ) );

        wp_enqueue_style( 'sliding-widgetopts-styles' );
    }
    add_action( 'wp_enqueue_scripts', 'widgetopts_slidein_load_scripts' );
    add_action( 'customize_controls_enqueue_scripts', 'widgetopts_slidein_load_scripts' );
endif;

if( !function_exists( 'widgetopts_slidein_admin_scripts' ) ):
    function widgetopts_slidein_admin_scripts(){
        global $widget_options, $pagenow;

        $parent  = '';
        $js_dir  = SLIDING_WIDGETOPTS_PLUGIN_URL . 'assets/js/';
        $css_dir = SLIDING_WIDGETOPTS_PLUGIN_URL . 'assets/css/';

        // Use minified libraries if SCRIPT_DEBUG is turned off
        $suffix  = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '.min';

        if( in_array( $pagenow, apply_filters( 'widgetopts_slidein-admin_scripts', array( 'widgets.php', 'customize.php' ) ) ) ){

            // wp_register_style( 'sliding-widgetopts-styles', $css_dir . 'sliding-widgetopts.css' , array(), null );

            wp_enqueue_style( 'wp-color-picker' );
            wp_enqueue_script( 'wp-color-picker' );
            wp_enqueue_script(
                'sliding-widgetopts-admin',
                $js_dir .'widgets'. $suffix .'.js',
                array( 'jquery' ),
                '',
                true
            );

            if( defined( 'WIDGETOPTS_PLUGIN_NAME' ) && WIDGETOPTS_PLUGIN_NAME == 'Extended Widget Options' ){
                $parent = 'extended';
            }else if( defined( 'WIDGETOPTS_PLUGIN_NAME' ) && WIDGETOPTS_PLUGIN_NAME == 'Widget Options' ){
                $parent = 'core';
            }

            wp_localize_script( 'sliding-widgetopts-admin', 'widgetoptsSL', array( 'parent' => $parent ) );

            wp_enqueue_style( 'sliding-widgetopts-styles' );
        }

        if( $pagenow == 'options-general.php' ){
            $screen = get_current_screen();
            if( isset( $screen->base ) && $screen->base == 'settings_page_widgetopts_plugin_settings' ){
                wp_enqueue_style( 'wp-color-picker' );
                wp_enqueue_script('wp-color-picker');

                wp_enqueue_script(
                    'sliding-widgetopts-admin',
                    $js_dir .'settings'. $suffix .'.js',
                    array( 'jquery' ),
                    '',
                    true
                );
            }
        }
    }
    add_action( 'admin_enqueue_scripts', 'widgetopts_slidein_admin_scripts', 100 );
endif;
?>
