<?php
/**
 * Widgets on Menu Settings Module
 * Settings > Widget Options :: Widgets on Menu
 *
 * @copyright   Copyright (c) 2017, Jeffrey Carandang
 * @since       1.0
*/

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Create Card Module for Widgets on Menu Options
 *
 * @since 1.0
 * @return void
 */
if( !function_exists( 'widgetopts_settings_sliding' ) ):
	function widgetopts_settings_sliding(){
		global $widget_options;
		$option  = ( isset( $widget_options['sliding'] ) ) ? $widget_options['sliding'] : '';
		$sliding = ( isset( $widget_options['settings']['sliding'] ) ) ? $widget_options['settings']['sliding'] : array(); ?>

		<li class="widgetopts-module-card <?php echo ( $option == 'activate' ) ? 'widgetopts-module-type-enabled' : 'widgetopts-module-type-disabled'; ?>" id="widgetopts-module-card-sliding" data-module-id="sliding">
			<div class="widgetopts-module-card-content">
				<h2><?php _e( 'Sliding Widgets', 'widget-options' );?></h2>
				<div class="widgetopts-pro-label"><span class="dashicons dashicons-unlock"></span></div>
				<p class="widgetopts-module-desc">
					<?php _e( 'Transform your widgets to slide-in, pull-out and/or modal popup!', 'widget-options' );?>
				</p>
				<?php //print_r( $visibility );?>
				<div class="widgetopts-module-actions hide-if-no-js">
					<?php if( $option == 'activate' ){ ?>
						<button class="button button-secondary widgetopts-toggle-settings"><?php _e( 'Configure Settings', 'widget-options' );?></button>
						<button class="button button-secondary widgetopts-toggle-activation"><?php _e( 'Disable', 'widget-options' );?></button>
					<?php }else{ ?>
						<button class="button button-secondary widgetopts-toggle-settings"><?php _e( 'Learn More', 'widget-options' );?></button>
						<button class="button button-primary widgetopts-toggle-activation"><?php _e( 'Enable', 'widget-options' );?></button>
					<?php } ?>

				</div>
			</div>

			<?php widgetopts_modal_start( $option ); ?>
				<span class="dashicons widgetopts-dashicons widgetopts-no-top dashicons-exerpt-view"></span>
				<h3 class="widgetopts-modal-header"><?php _e( 'Sliding Widgets', 'widget-options' );?></h3>
				<p>
					<?php _e( 'Sliding Widgets is a premium add-on to maximize your widgets usage and turn any of your widgets to slide-ins, pull-outs and/or modal pop-up! Take the next level and add triggers to capture your user attentions on page load, while scrolling on your contents and even on exit intents.', 'widget-options' );?>
				</p>
				<table class="form-table widgetopts-settings-section">
					<tr>
						<th scope="row">
							<label for="widgetopts-sliding-top"><?php _e( 'Space from Top', 'widget-options' );?></label>
						</th>
						<td>
							<table>
								<tr>
									<td>
										<small><?php _e( 'Desktop & Tablet', 'widget-options' );?></small><br />
										<input type="text" id="widgetopts-sliding-top" name="sliding[top]" value="<?php echo ( isset( $sliding['top'] ) ) ? $sliding['top'] : ''; ?>" size="5" /><?php _e( 'pixels', 'widget-options' );?>
									</td>
									<td>
										<small><?php _e( 'Mobile Devices', 'widget-options' );?></small><br />
										<input type="text" id="widgetopts-sliding-top_mobile" name="sliding[top_mobile]" value="<?php echo ( isset( $sliding['top_mobile'] ) ) ? $sliding['top_mobile'] : ''; ?>" size="5" /><?php _e( 'pixels', 'widget-options' );?>
									</td>
								</tr>
							</table>
							<p class="description">
								<?php _e( 'Space from top of the left and right button. Leave blank for default.', 'widget-options' );?>
							</p>
						</td>
					</tr>
					<tr>
						<th scope="row">
							<label for="widgetopts-sliding-bg"><?php _e( 'Content Background Color', 'widget-options' );?></label>
						</th>
						<td>
							<input type="text" id="widgetopts-sliding-bg" class="sl-widgetopts-color" name="sliding[bg]" value="<?php echo ( isset( $sliding['bg'] ) ) ? $sliding['bg'] : ''; ?>" />
							<p class="description">
								<?php _e( 'Assign default widget content background color.', 'widget-options' );?>
							</p>
						</td>
					</tr>
					<tr>
						<th scope="row">
							<label for="widgetopts-sliding-text"><?php _e( 'Content Text Color', 'widget-options' );?></label>
						</th>
						<td>
							<input type="text" id="widgetopts-sliding-text" class="sl-widgetopts-color" name="sliding[text]" value="<?php echo ( isset( $sliding['text'] ) ) ? $sliding['text'] : ''; ?>" />
							<p class="description">
								<?php _e( 'Assign default widget content text color.', 'widget-options' );?>
							</p>
						</td>
					</tr>
					<tr>
						<th scope="row">
							<label for="widgetopts-sliding-link"><?php _e( 'Content Link Color', 'widget-options' );?></label>
						</th>
						<td>
							<input type="text" id="widgetopts-sliding-link" class="sl-widgetopts-color" name="sliding[link]" value="<?php echo ( isset( $sliding['link'] ) ) ? $sliding['link'] : ''; ?>" />
							<p class="description">
								<?php _e( 'Assign default color for link contents.', 'widget-options' );?>
							</p>
						</td>
					</tr>
					<tr>
						<th scope="row">
							<label for="widgetopts-sliding-credits"><?php _e( 'Support Us', 'widget-options' );?></label>
						</th>
						<td>
							<input type="checkbox" id="widgetopts-sliding-credits" name="sliding[credits]" <?php echo ( isset( $widget_options['settings']['sliding'] ) ) ? widgetopts_is_checked( $widget_options['settings']['sliding'], 'credits' ) : ''; ?> value="1" />
							<label for="widgetopts-sliding-credits"><?php _e( 'Display Powered By', 'widget-options' );?></label>
							<p class="description">
								<?php _e( 'Enabling this feature will display Powered By Link below each sliding widgets. Thank you very much for supporting us!', 'widget-options' );?>
							</p>
						</td>
					</tr>
					<tr>
						<td colspan="2"><?php _e( 'You can add widget specific colors and styling when you are using <a href="https://widget-options.com?utm_source=wordpressadmin&utm_medium=sliding&utm_campaign=slidingbg" target="_blank">Extended Widget Options</a>.', 'widget-options' );?></td>
					</tr>
				</table>

				<h4>
					<?php _e( 'Open Manually via Link Instructions', 'widget-options' );?>
				</h4>
				<ol style=" font-size: 14px;">
					<li>
						<?php _e( 'On the Slide-in widget options tab, copy the value under <strong>Widget ID</strong>.', 'widget-options' );?>
					</li>
					<li>
						<?php _e( 'Use the copied value as <strong>href</strong> link attribute value.', 'widget-options' );?>
					</li>
					<li>
						<?php _e( 'Add <strong>sl-widgetopts-open</strong> class on the link.', 'widget-options' );?>
					</li>
					<li>
						<?php _e( 'Your link html code should be like this whereas href value should be changed :<br /> <code>&#60;a href="#text-15" class="sl-widgetopts-open"&#62;Toggle Widget&#60;/a&#62;</code>', 'widget-options' );?>
					</li>
				</ol>

				<style>
				.widgetopts-settings-section tr table{
					padding: 0px;
					margin: 0px;
				}
				.widgetopts-settings-section tr table td{
					padding: 0px 50px 0px 0px;
				}
				.widgetopts-settings-section tr table small{
					font-weight: 500;
				}
				</style>
			<?php widgetopts_modal_end( $option ); ?>

		</li>
	    <?php
	}
endif;
?>
