<?php
/**
 * Welcome Page Class
 *
 * @copyright   Copyright (c) 2017, Jeffrey Carandang
 * @since       1.0
 */
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;
/**
 * SLWIDGETOPS_Welcome Class
 *
 * A general class for About and Credits page.
 *
 * @since 1.0
 */

if( !class_exists( 'SLWIDGETOPS_Welcome' ) ){
    class SLWIDGETOPS_Welcome{
        public function __construct() {
			if ( is_admin() ) {
				add_action( 'admin_enqueue_scripts', array($this, 'enqueue') );
				add_action( 'admin_menu', array($this, 'screen_page') );
				add_action( 'activated_plugin', array($this, 'redirect' ) );
				add_action( 'admin_head', array($this, 'remove_menu' ) );
			}
		}

		function enqueue(){
			if ( !isset( $_GET['page'] ) || 'sliding-widgetopts-getting-started' != $_GET['page'] )
			return;

			wp_enqueue_style( 'extended-widget-opts-welcome', WIDGETOPTS_PLUGIN_URL .'/assets/css/welcome.css' , array(), null );
		}

		function screen_page(){
			add_dashboard_page(
				__( 'Getting started with Sliding Widget Options Add-on', 'widget-options' ),
				__( 'Getting started with Sliding Widget Options Add-on', 'widget-options' ),
				apply_filters( 'widgetopts_sliding_welcome_cap', 'manage_options' ),
				'sliding-widgetopts-getting-started',
				array( $this, 'welcome_content' )
			);
		}

		function welcome_head(){
			$selected = isset( $_GET['page'] ) ? $_GET['page'] : 'sliding-widgetopts-getting-started';
			?>
			<h1><?php _e( 'Welcome to Sliding Widget Options Add-on', 'widget-options' ); ?></h1>
			<div class="about-text">
				<?php _e( 'Congratulations you can now transform your widgets to the next level! You now have options to turn your WordPress widgets into modal pop-up, slide-in and/or sliding panel at ease.', 'widget-options' ); ?>
			</div>
			<div class="widgetopts-badge">
				<span class="widgetopts-mascot"></span>
				<span class="version"><?php _e( 'Version', 'widget-options' );?> <?php echo SLIDING_WIDGETOPTS_PLUGIN_VERSION; ?></span>
			</div>
			<h2 class="nav-tab-wrapper">
				<a class="nav-tab <?php echo $selected == 'sliding-widgetopts-getting-started' ? 'nav-tab-active' : ''; ?>" href="<?php echo esc_url( admin_url( add_query_arg( array( 'page' => 'sliding-widgetopts-getting-started' ), 'index.php' ) ) ); ?>">
					<?php _e( 'Getting Started', 'widget-options' ); ?>
				</a>
			</h2>
			<?php
		}

		function welcome_content(){ ?>
			<div class="wrap about-wrap widgetopts-about-wrap">
				<?php $this->welcome_head(); ?>
				<p class="about-description">
					<?php _e( 'Use the tips and instructions below to get started, then you will be up and running in no time. ', 'widget-options' ); ?>
				</p>

				<div class="feature-section two-col">
					<div class="col">
						<h3><?php _e( 'Easily transform your widgets!' , 'widget-options' ); ?></h3>
						<p><?php printf( __( 'Sliding Widget Options Add-on will give you additional widget options to get more user engagement on your website. To get started go to <strong> <a href="%s" target="_blank">Settings > Widget Options</a></strong> and <strong>enable Sliding Widgets</strong> module. Then watch the video on the right to see how easy it is to turn any of your widgets to modal pop-up, slide-in and sliding widgets!', 'widget-options' ), esc_url( admin_url('options-general.php?page=widgetopts_plugin_settings') ) ); ?>
					</div>
					<div class="col">
						<div class="feature-video">
							<iframe width="495" height="278" src="https://www.youtube.com/embed/u_WhfzUBm-0" frameborder="0" allowfullscreen></iframe>
						</div>
					</div>
				</div>

				<div class="feature-section two-col">
					<h3><?php _e( 'We are always here to help!', 'widget-options' ); ?></h3>
					<p style="margin-left: 0px;"><?php _e( 'We at PHPBITS Creative Studio are always here to help you out if in any case you encounter any issues or having hard time figuring the plugin out. Feel free to contact our <a href="https://phpbits.net/contact/" target="_blank">support page</a> and we will be very happy to assist you. Thank your very much!', 'widget-options' ); ?></p>
				</div>
			</div>
		<?php }

		function redirect($plugin){
			if($plugin=='sliding-widget-options/plugin.php') {
				wp_redirect(admin_url('index.php?page=sliding-widgetopts-getting-started'));
				die();
			}
		}
		function remove_menu(){
		    remove_submenu_page( 'index.php', 'sliding-widgetopts-getting-started' );
		}
    }
    new SLWIDGETOPS_Welcome();
}

?>
