<?php
/**
 * Configure Widgets Display on Frontend
 * @since   1.0
*/
// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

if( !function_exists( 'sliding_widgetopts_before_widgets' ) ):
    add_filter( 'dynamic_sidebar_params', 'sliding_widgetopts_before_widgets', 90 );
    function sliding_widgetopts_before_widgets( $params ){
        if( is_admin() ){
            return $params;
        }

        global $widget_options, $wp_registered_widget_controls;

        $id_base        = $wp_registered_widget_controls[ $params[0]['widget_id'] ]['id_base'];
        $instance       = get_option( 'widget_' . $id_base );

        if( isset( $wp_registered_widget_controls[ $params[0]['widget_id'] ]['params'][0]['number'] ) ){
            $num = $wp_registered_widget_controls[ $params[0]['widget_id'] ]['params'][0]['number'];
        }elseif( isset( $wp_registered_widget_controls[ $params[0]['widget_id'] ]['callback'][0]->number ) ){
            $num = $wp_registered_widget_controls[ $params[0]['widget_id'] ]['callback'][0]->number;
        }else{
            $num = substr( $params[0]['widget_id'], -1 );
        }
        if( isset( $instance[ $num ] ) ){
            $opts           = ( isset( $instance[ $num ][ 'extended_widget_opts-'. $params[0]['widget_id'] ] ) ) ? $instance[ $num ][ 'extended_widget_opts-'. $params[0]['widget_id'] ] : array();
        }else{
            $opts = array();
        }

        //defaults
        $slidein        = array();
        $classes        = '';
        $in_classes     = '';
        $style          = '';
        $direction      = '';
        $placement      = 'bottom';
        $settings       = ( isset( $widget_options['settings'] ) && isset( $widget_options['settings']['sliding'] ) ) ? $widget_options['settings']['sliding'] : array();

        if( isset( $opts ) && isset( $opts['slidein'] ) ){
            $slidein = $opts['slidein'];

            $selected      = ( isset( $slidein[ 'enable' ] ) )      ? $slidein[ 'enable' ]   : 0;

            //check if slidein is enable
            if( '1' == $selected ){

                $position      = ( isset( $slidein[ 'position' ] ) )    ? $slidein[ 'position' ] : 'top-left';
                $type          = ( isset( $slidein[ 'type' ] ) )        ? $slidein[ 'type' ]     : 'slide';
                $open          = ( isset( $slidein[ 'open' ] ) )        ? $slidein[ 'open' ]     : 'none';
                $hide          = ( isset( $slidein[ 'hide' ] ) )        ? $slidein[ 'hide' ]     : '';
                $text          = ( isset( $slidein[ 'text' ] ) )        ? $slidein[ 'text' ]     : '';
                $caret         = ( isset( $slidein[ 'caret' ] ) )       ? $slidein[ 'caret' ]    : '';

                $icon          = ( isset( $slidein[ 'icon' ] ) )        ? $slidein[ 'icon' ]     : 'no-icon';
                $hidden        = ( isset( $slidein[ 'hidden' ] ) )      ? $slidein[ 'hidden' ]   : '';
                $stype         = ( isset( $slidein[ 'onScroll' ] ) )    ? $slidein[ 'onScroll' ] : '%';
                $scroll        = ( isset( $slidein[ 'scroll' ] ) )      ? $slidein[ 'scroll' ]   : '';
                $trigger       = ( isset( $slidein[ 'trigger' ] ) )     ? $slidein[ 'trigger' ]  : 'once';
                $open_trigger  = ( isset( $slidein[ 'open_trigger' ] ) )? $slidein[ 'open_trigger' ]  : 'click';
                $width         = ( isset( $slidein[ 'width' ] ) )       ? intval( $slidein[ 'width' ] )     : '';
                $color         = ( isset( $slidein[ 'color' ] ) )       ? $slidein[ 'color' ]               : '';
                $background    = ( isset( $slidein[ 'background' ] ) )  ? $slidein[ 'background' ]          : '';

                //inner classes
                if( 'scroll' == $open ){
                    $in_classes    .= ' sl-widgetopts-scroll';
                }
                if( in_array( $type, array( 'slidein-left', 'slidein-right' ) ) ){
                    $t          = explode( '-', $type );
                    $type       = $t[0];
                    $direction  = $t[1];
                    $classes    .= ' sl-widgetopts-slidein';
                    $classes    .= ' sl-widgetopts-sl-' . $t[1];
                }else{
                    $classes    .= ' sl-widgetopts-'. $type;

                    if( $type == 'slide' ){
                        $in_classes .= ' sl-widgetopts-inner';
                    }
                }
                if( $open_trigger == 'hover' ){
                    $in_classes .= ' sl-widgetopts-w-mo';
                }

                $classes    .= ' sl-widgetopts-'. $open;

                if( !empty( $hide ) ){
                    $classes    .= ' sl-widgetopts-i-d';
                }

                if( !empty( $hidden ) ){
                    $classes    .= ' sl-widgetopts-l-m';
                }
                if( !empty( $width ) ){
                    $classes    .= ' sl-widgetopts-w';
                }

                if( 'no-icon' == $icon && empty( $text )  ){
                    $classes    .= ' sl-widgetopts-empty-l';
                }

                if( $position == 'top-left' ){
                    $placement  = 'left';
                }else if( $position == 'top-right' ){
                    $placement  = 'right';
                }


                //assign color
                if( !empty( $color ) ){
                    $style .= 'color:' . $color .';';
                }else if( isset( $settings['text'] ) && !empty( $settings['text'] ) ){
                    $style .= 'color:' . $settings['text'] .';';
                }else{
                    $style .= 'color: #FFFFFF;';
                }

                //set bg
                if( !empty( $background ) ){
                    $style .= 'background:' . $background .';';
                }else if( isset( $settings['bg'] ) && !empty( $settings['bg'] ) ){
                    $style .= 'background:' . $settings['bg'] .';';
                }else{
                    $style .= 'background: #292e3a;';
                }

                // $style         .= ( isset( $slidein[ 'background' ] ) )  ? 'background:' . $background .';'    : '';

                //add device visibility class for compatibility
                $devices        = isset( $opts['devices'] )     ? $opts['devices'] : '';
                if( isset( $devices['options'] ) ){
                    unset( $devices['options'] );
                }

                if( 'activate' == $widget_options['devices'] ){
                    //devices visibility
                    if( !empty( $devices ) ){
                        $device_opts    = ( isset( $opts['devices']['options'] ) ) ? $opts['devices']['options'] : 'hide';
                        $classes .= ' sl-widgetopts-' . $device_opts ;

                        foreach ($devices as $key => $value) {
                            $classes .= ' sl-widgetopts-' . $key;
                        }
                    }
                }

                $before  = '<div class="sl-widgetopts-wrp slwidgetopts-'. $params[0]['widget_id'] .' '. $classes .' sl-widgetopts-'. $position .'" style="opacity: 0;"><div class="sliding-widgetopts '. $in_classes .'" data-widgetid="'. $params[0]['widget_id'] .'" data-width="'. $width .'" data-scroll="'. $scroll .'" data-sctype="'. $stype .'" data-direction="'. $direction .'" data-trigger="'. $trigger .'" data-sltype="'. $type .'" data-position="'. $position .'" data-placement="'. $placement .'">';
                $before .= '<a href="#" class="sl-widgetopts-lbl '. ( ( $open_trigger == 'hover' ) ? 'sl-widgetopts-mo' : '' ) .' '. ( ( 'no-icon' != $icon ) ? 'sl-widgetopts-lx' : 'sl-widgetopts-lv' ) .' sl-widgetopts-o '. ( ( !empty( $caret ) ) ? 'sl-widgetopts-nc' : '' ) .'" style="'. $style .'" data-color="'. $color .'" data-bg="'. $background .'">';
                if( 'no-icon' != $icon ){
                    $before .= '<span class="sl-widgetopts-o sl-widgetopts-ic dashicons '. $icon .'"></span>';
                }

                if( !empty( $text ) ){
                    $before .= '<span class="sl-widgetopts-t sl-widgetopts-o '. ( ( $open_trigger == 'hover' ) ? 'sl-widgetopts-mo' : '' ) .'">'. $text .'</span>';
                }

                if( empty( $caret ) ){
                    $before .= '<span class="dashicons dashicons-arrow-up-alt2 sl-widgetopts-o '. ( ( $open_trigger == 'hover' ) ? 'sl-widgetopts-mo' : '' ) .' sl-widgetopts-c"></span>';
                }
                $before .= '</a>';

                if( $type == 'slidein' ){
                    $before .= '<div class="sl-widgetopts-w-in sl-widgetopts-inner">';
                }

                $params[0]['before_widget']  = $before . $params[0]['before_widget'];
                $params[0]['after_widget']   = $params[0]['after_widget'] . '';

                if( ( isset( $widget_options['settings']['sliding'] ) && isset( $widget_options['settings']['sliding']['credits'] ) &&  $widget_options['settings']['sliding']['credits'] == '1' ) &&
                  ( $type == 'slide' || $type == 'slidein' ) ){
                    $params[0]['after_widget'] .= '<span class="sl-wopts-credits"><a href="https://widget-options.com/modal-pop-up-and-sliding-widget-options/" target="_blank"><span class="dashicons dashicons-admin-plugins"></span> '. __( 'Sliding Widget Options Add-on', 'widget-options' ) .'</a></span>';
                }

                $params[0]['after_widget']  .= '</div></div>';

                if( $type == 'slidein' ){
                    $params[0]['after_widget'] .= '</div>';
                }
            }
        }

        //sample
        // if( $params[0]['widget_id'] == 'recent-posts-7' ){
        //     $before  = '<div class="sl-widgetopts-wrp sl-widgetopts-sl-r sl-widgetopts-btmrght"><div class="sliding-widgetopts sl-widgetopts-scroll" data-scroll="70" data-sctype="percent" data-direction="right" data-sltype="slide" data-position="bottom-right" data-placement="bottom">';
        //     $before .= '<a href="#" class="sl-widgetopts-lbl sl-widgetopts-o" style="/**position: absolute;**/"><span class="sl-widgetopts-t sl-widgetopts-o">'. $params[0]['widget_name'] .'</span><span class="sl-widgetopts-c sl-widgetopts-o"></span></a>';
        //
        //     $params[0]['before_widget']  = $before . $params[0]['before_widget'];
        //     $params[0]['after_widget']   = $params[0]['after_widget'] . '</div></div>';
        // }
        // if( $params[0]['widget_id'] == 'search-6' ){
        //     $before  = '<div class="sl-widgetopts-wrp sl-widgetopts-enter sl-widgetopts-modal sl-widgetopts-tplft"><div class="sliding-widgetopts" data-sltype="modal" data-widgetid="'. $params[0]['widget_id'] .'" data-position="top-left" data-placement="left">';
        //     $before .= '<a href="#" class="sl-widgetopts-lbl sl-widgetopts-o" style="/**position: absolute;**/"><span class="sl-widgetopts-t sl-widgetopts-o">'. $params[0]['widget_name'] .'</span><span class="sl-widgetopts-c sl-widgetopts-o"></span></a>';
        //
        //     $params[0]['before_widget']  = $before . $params[0]['before_widget'];
        //     $params[0]['after_widget']   = $params[0]['after_widget'] . '</div></div>';
        // }
        // if( $params[0]['widget_id'] == 'recent-posts-5' ){
        //     $before  = '<div class="sl-widgetopts-wrp sl-widgetopts-btmrght sl-widgetopts-slidein sl-widgetopts-sl-r"><div class="sliding-widgetopts" data-sltype="slidein" data-direction="right" data-position="bottom-right" data-placement="bottom">';
        //     $before .= '<a href="#" class="sl-widgetopts-lbl sl-widgetopts-o" style="/**position: absolute;**/"><span class="sl-widgetopts-t sl-widgetopts-o">'. $params[0]['widget_name'] .'</span><span class="sl-widgetopts-c sl-widgetopts-o"></span></a>';
        //
        //     $params[0]['before_widget']  = $before . $params[0]['before_widget'];
        //     $params[0]['after_widget']   = $params[0]['after_widget'] . '</div></div>';
        // }
        // if( $params[0]['widget_id'] == 'text-7' ){
        //     $before  = '<div class="sl-widgetopts-wrp sl-widgetopts-exit sl-widgetopts-tprght"><div class="sliding-widgetopts" data-sltype="slide" data-widgetid="'. $params[0]['widget_id'] .'" data-position="top-right" data-placement="right">';
        //     $before .= '<a href="#" class="sl-widgetopts-lbl sl-widgetopts-o" style="position: absolute;"><span class="sl-widgetopts-t sl-widgetopts-o">'. $params[0]['widget_name'] .'</span><span class="sl-widgetopts-c sl-widgetopts-o"></span></a>';
        //
        //     $params[0]['before_widget']  = $before . $params[0]['before_widget'];
        //     $params[0]['after_widget']   = $params[0]['after_widget'] . '</div></div>';
        // }
        return $params;
    }
endif;

add_action( 'wp_footer', 'sliding_widgetopts_footer' );
function sliding_widgetopts_footer(){
    global $widget_options;
    if( isset( $widget_options['sliding'] ) && 'activate' == $widget_options['sliding'] ){
        $style = ( isset( $widget_options['settings']['sliding'] ) ) ? $widget_options['settings']['sliding'] : array(); ?>
        <style type="text/css">
            <?php echo '.sl-widgetopts-inner, .sl-wopts-credits{ background: '. ( ( isset( $style['bg'] ) && !empty( $style['bg'] ) ) ? $style['bg'] : '#292e3a' ) .'; }'; ?>
            <?php echo '.sl-widgetopts-inner, .sl-widgetopts-inner p, .sl-widgetopts-inner label, .sl-widgetopts-inner .widgettitle{ color: '. ( ( isset( $style['text'] ) && !empty( $style['text'] ) ) ? $style['text'] : '#FFFFFF' ) .';  }'; ?>
            <?php echo ( isset( $style['link'] ) && !empty( $style['link'] ) ) ? '.sl-widgetopts-inner a, .sl-wopts-credits a{ color: '. $style['link'] .';  }' : '.sl-wopts-credits a{ color: #FFFFFF; }'; ?>

        </style>
        <div id="sliding-widgetopts-widgets">
            <?php dynamic_sidebar( 'sliding-widgetopts' ); ?>
        </div>
        <?php
        echo '<div id="sl-widgetopts-overlay" class="sl-widgetopts-modaloff"></div><div id="sl-widgetopts-footer" class="sl-widgetopts-inner"><span class="sl-widgetopts-modaloff sl-widgetopts-modalx"><a href="#" onclick="return false;" class="sl-widgetopts-modaloff"><span class="sl-widgetopts-modaloff dashicons dashicons-no-alt"></span></a></span><div id="sl-widgetopts-footer-in"></div>';

        if( ( isset( $widget_options['settings']['sliding'] ) && isset( $widget_options['settings']['sliding']['credits'] ) &&  $widget_options['settings']['sliding']['credits'] == '1' ) ){
            echo '<span class="sl-wopts-credits"><a href="https://widget-options.com/modal-pop-up-and-sliding-widget-options/" target="_blank"><span class="dashicons dashicons-admin-plugins"></span> '. __( 'Sliding Widget Options Add-on', 'widget-options' ) .'</a></span>';
        }

        echo '</div>';
    }
}

//fix for Gravity Forms

// if( !function_exists( 'widgetopts_sliding_render_display' ) ){
//     add_filter( 'widgetopts_cached_display', 'widgetopts_sliding_render_display', 10, 5 );
//     function widgetopts_sliding_render_display( $widget, $instance, $widget_id ){
//         $opts = ( isset( $instance[ 'extended_widget_opts-'. $widget_id ] ) ) ? $instance[ 'extended_widget_opts-'. $widget_id ] : array();
//
//         if( isset( $opts ) && isset( $opts['slidein'] ) ){
//             $slidein  = $opts['slidein'];
//
//             $selected = ( isset( $slidein[ 'enable' ] ) ) ? $slidein[ 'enable' ] : 0;
//
//             //check if slidein is enable
//             if( '1' == $selected ){
//                 $type = ( isset( $slidein[ 'type' ] ) )   ? $slidein[ 'type' ]   : 'slide';
//                 if( $type == 'modal' ){
//                     //remove <scripts> inside the widget contents
//                     $regex = "/<script[^>]*>(?:.*?<\/script>)?/i";
//
//                     preg_match_all( $regex, $widget, $scripts );
//                     $widget = preg_replace( '#<script(.*?)>(.*?)</script>#is', '', $widget );
//
//                     if( !empty( $scripts ) ){
//                         foreach ( $scripts as $script ) {
//                             if( is_array( $script ) ){
//                                 foreach ( $script as $s ) {
//                                     $widget .= $s;
//                                 }
//                             }else{
//                                 $widget .= $script;
//                             }
//                         }
//                     }
//                 }
//             }
//         }
//         return $widget;
//     }
// }
// add_filter('gform_init_scripts_footer', '__return_true');
//
// add_filter( 'gform_cdata_open', 'wrap_gform_cdata_open' );
// function wrap_gform_cdata_open( $content = '' ) {
// 	$content = 'document.addEventListener( "Sliding_Widgets_Loaded", function() { ';
// 	return $content;
// }
// add_filter( 'gform_cdata_close', 'wrap_gform_cdata_close' );
// function wrap_gform_cdata_close( $content = '' ) {
// 	$content = ' }, false );';
// 	return $content;
// }
?>
