<?php
/**
 * Add option tabs on Styling tab for Sliding settings
 * @since   1.0
*/
// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

if( !function_exists( 'sliding_widgetopts_options_init' ) ):
    add_action( 'admin_init', 'sliding_widgetopts_options_init' );
    function sliding_widgetopts_options_init(){
        if( defined( 'WIDGETOPTS_PLUGIN_NAME' ) && WIDGETOPTS_PLUGIN_NAME == 'Extended Widget Options'  ){
            add_action( 'extended_widgetopts_tabnav_styling', 'sliding_widgetopts_options_tabnav' );
            add_action( 'extended_widgetopts_tabcontents_styling', 'sliding_widgetopts_options_tab' );
            add_action( 'widgetopts_module_cards', 'widgetopts_settings_sliding', 210 );
        }else if( defined( 'WIDGETOPTS_PLUGIN_NAME' ) && WIDGETOPTS_PLUGIN_NAME == 'Widget Options' ){
            add_action( 'extended_widget_opts_tabs', 'sliding_widgetopts_options_tabnav', 40 );
            add_action( 'extended_widget_opts_tabcontent', 'sliding_widgetopts_options_tab');
            add_action( 'widgetopts_module_cards', 'widgetopts_settings_sliding', 67 );
        }
    }
endif;
if( !function_exists( 'sliding_widgetopts_options_tabnav' ) ):
    function sliding_widgetopts_options_tabnav( $args ){ ?>
        <li class="extended-widget-opts-styling-tab-slidein">
            <a href="#extended-widget-opts-styling-tab-<?php echo $args['id'];?>-slidein" >
                <?php
                if( defined( 'WIDGETOPTS_PLUGIN_NAME' ) && WIDGETOPTS_PLUGIN_NAME == 'Extended Widget Options'  ){
                     _e( 'Slide-in', 'widget-options' );
                }else if( defined( 'WIDGETOPTS_PLUGIN_NAME' ) && WIDGETOPTS_PLUGIN_NAME == 'Widget Options' ){ ?>
                    <span class="dashicons dashicons-arrow-up-alt2"></span>
                    <span class="tabtitle"><?php _e( 'Slide-in', 'widget-options' );?></span>
                <?php } ?>
            </a>
        </li>
    <?php }
endif;

if( !function_exists( 'sliding_widgetopts_options_tab' ) ):
    function sliding_widgetopts_options_tab( $args ){ ?>
        <div id="extended-widget-opts-styling-tab-<?php echo $args['id'];?>-slidein" class="extended-widget-opts-styling-tabcontent extended-widget-opts-inner-tabcontent">
            <?php sliding_widgetopts_options_tabcontent( $args );?>
        </div>
    <?php }
endif;

if( !function_exists( 'sliding_widgetopts_options_tabcontent' ) ):
    function sliding_widgetopts_options_tabcontent( $args ){
        global $widget_options;

        $dashicons = apply_filters( 'sl-widgetopts_dashicons', array() ); // REMOVE LATER
		$dashicons = apply_filters( 'sl-widgetopts/dashicons', $dashicons );

        //defaults
        $slidein   = array();

        if( isset( $args['params'] ) && isset( $args['params']['slidein'] ) ){
            $slidein = $args['params']['slidein'];
        }

        $selected      = ( isset( $slidein[ 'enable' ] ) )      ? $slidein[ 'enable' ]   : 0;
        $position      = ( isset( $slidein[ 'position' ] ) )    ? $slidein[ 'position' ] : 'top-left';
        $width         = ( isset( $slidein[ 'width' ] ) )       ? $slidein[ 'width' ]    : '';
        $type          = ( isset( $slidein[ 'type' ] ) )        ? $slidein[ 'type' ]     : 'slide';
        $open          = ( isset( $slidein[ 'open' ] ) )        ? $slidein[ 'open' ]     : 'none';
        $hide          = ( isset( $slidein[ 'hide' ] ) )        ? $slidein[ 'hide' ]     : '';
        $text          = ( isset( $slidein[ 'text' ] ) )        ? $slidein[ 'text' ]     : '';
        $caret         = ( isset( $slidein[ 'caret' ] ) )       ? $slidein[ 'caret' ]    : '';
        $color         = ( isset( $slidein[ 'color' ] ) )       ? $slidein[ 'color' ]    : '';
        $background    = ( isset( $slidein[ 'background' ] ) )  ? $slidein[ 'background' ]    : '';
        $icon          = ( isset( $slidein[ 'icon' ] ) )        ? $slidein[ 'icon' ]     : 'no-icon';
        $hidden        = ( isset( $slidein[ 'hidden' ] ) )      ? $slidein[ 'hidden' ]   : '';
        $stype         = ( isset( $slidein[ 'onScroll' ] ) )    ? $slidein[ 'onScroll' ] : 'percent';
        $scroll        = ( isset( $slidein[ 'scroll' ] ) )      ? $slidein[ 'scroll' ]   : '';
        $trigger       = ( isset( $slidein[ 'trigger' ] ) )     ? $slidein[ 'trigger' ]  : 'once';
        $open_trigger  = ( isset( $slidein[ 'open_trigger' ] ) )     ? $slidein[ 'open_trigger' ]  : 'click';
        ?>
        <p class="widgetopts-subtitle">
            <label for="extended_widget_opts-<?php echo $args['id'];?>-enable">
                <input type="checkbox" name="<?php echo $args['namespace'];?>[extended_widget_opts][slidein][enable]" id="extended_widget_opts-<?php echo $args['id'];?>-enable" value="1" <?php echo ( '1' == $selected ) ? 'checked="checked"' : '';?> >
                <?php _e( 'Check to Enable', 'widget-options' );?>
            </label>
        </p>
        <ul class="sliding_widgetopts-tab-opts">
            <li>
                <p><strong><?php _e( 'Position', 'widget-options' );?></strong></p>
                <label class="widgetopts-img-box <?php echo ( 'top-left' == $position ) ? 'widgetopts-img-box-c' : '';?>" for="extended_widget_opts-<?php echo $args['id'];?>-tplft">
                    <img src="<?php echo SLIDING_WIDGETOPTS_PLUGIN_URL;?>/assets/images/top-left.png" />
                    <input type="radio" name="<?php echo $args['namespace'];?>[extended_widget_opts][slidein][position]" id="extended_widget_opts-<?php echo $args['id'];?>-tplft" value="top-left" <?php echo ( 'top-left' == $position ) ? 'checked="checked"' : '';?> >
                </label>
                <label class="widgetopts-img-box <?php echo ( 'top-right' == $position ) ? 'widgetopts-img-box-c' : '';?>" for="extended_widget_opts-<?php echo $args['id'];?>-tprght">
                    <img src="<?php echo SLIDING_WIDGETOPTS_PLUGIN_URL;?>/assets/images/top-right.png" />
                    <input type="radio" name="<?php echo $args['namespace'];?>[extended_widget_opts][slidein][position]" id="extended_widget_opts-<?php echo $args['id'];?>-tprght" value="top-right" <?php echo ( 'top-right' == $position ) ? 'checked="checked"' : '';?> >
                </label>
                <label class="widgetopts-img-box <?php echo ( 'bottom-left' == $position ) ? 'widgetopts-img-box-c' : '';?>" for="extended_widget_opts-<?php echo $args['id'];?>-btlft">
                    <img src="<?php echo SLIDING_WIDGETOPTS_PLUGIN_URL;?>/assets/images/bottom-left.png" />
                    <input type="radio" name="<?php echo $args['namespace'];?>[extended_widget_opts][slidein][position]" id="extended_widget_opts-<?php echo $args['id'];?>-btlft" value="bottom-left" <?php echo ( 'bottom-left' == $position ) ? 'checked="checked"' : '';?> >
                </label>
                <label class="widgetopts-img-box <?php echo ( 'bottom-right' == $position ) ? 'widgetopts-img-box-c' : '';?>" for="extended_widget_opts-<?php echo $args['id'];?>-btrght">
                    <img src="<?php echo SLIDING_WIDGETOPTS_PLUGIN_URL;?>/assets/images/bottom-right.png" />
                    <input type="radio" name="<?php echo $args['namespace'];?>[extended_widget_opts][slidein][position]" id="extended_widget_opts-<?php echo $args['id'];?>-btrght" value="bottom-right" <?php echo ( 'bottom-right' == $position ) ? 'checked="checked"' : '';?> >
                </label>
            </li>

            <li>
                <p><strong><?php _e( 'Open Type', 'widget-options' );?></strong></p>
                <label class="widgetopts-img-box <?php echo ( 'slide' == $type ) ? 'widgetopts-img-box-c' : '';?>" for="extended_widget_opts-<?php echo $args['id'];?>-d">
                    <img src="<?php echo SLIDING_WIDGETOPTS_PLUGIN_URL;?>/assets/images/default.png" />
                    <input type="radio" name="<?php echo $args['namespace'];?>[extended_widget_opts][slidein][type]" id="extended_widget_opts-<?php echo $args['id'];?>-d" value="slide" <?php echo ( 'slide' == $type ) ? 'checked="checked"' : '';?> >
                </label>
                <label class="widgetopts-img-box <?php echo ( 'modal' == $type ) ? 'widgetopts-img-box-c' : '';?>" for="extended_widget_opts-<?php echo $args['id'];?>-m">
                    <img src="<?php echo SLIDING_WIDGETOPTS_PLUGIN_URL;?>/assets/images/modal.png" />
                    <input type="radio" name="<?php echo $args['namespace'];?>[extended_widget_opts][slidein][type]" id="extended_widget_opts-<?php echo $args['id'];?>-m" value="modal" <?php echo ( 'modal' == $type ) ? 'checked="checked"' : '';?> >
                </label>
                <label class="widgetopts-img-box <?php echo ( 'slidein-left' == $type ) ? 'widgetopts-img-box-c' : '';?>" for="extended_widget_opts-<?php echo $args['id'];?>-l">
                    <img src="<?php echo SLIDING_WIDGETOPTS_PLUGIN_URL;?>/assets/images/left-slidein.png" />
                    <input type="radio" name="<?php echo $args['namespace'];?>[extended_widget_opts][slidein][type]" id="extended_widget_opts-<?php echo $args['id'];?>-l" value="slidein-left" <?php echo ( 'slidein-left' == $type ) ? 'checked="checked"' : '';?> >
                </label>
                <label class="widgetopts-img-box <?php echo ( 'slidein-right' == $type ) ? 'widgetopts-img-box-c' : '';?>" for="extended_widget_opts-<?php echo $args['id'];?>-r">
                    <img src="<?php echo SLIDING_WIDGETOPTS_PLUGIN_URL;?>/assets/images/right-slidein.png" />
                    <input type="radio" name="<?php echo $args['namespace'];?>[extended_widget_opts][slidein][type]" id="extended_widget_opts-<?php echo $args['id'];?>-r" value="slidein-right" <?php echo ( 'slidein-right' == $type ) ? 'checked="checked"' : '';?> >
                </label>
            </li>
            <li class="extended_widget_opts-txt">
                <p><strong><?php _e( 'Trigger', 'widget-options' );?></strong></p>
                <label class="widgetopts-img-box widgetopts-img-box-s <?php echo ( 'click' == $open_trigger ) ? 'widgetopts-img-box-c' : '';?>" for="extended_widget_opts-<?php echo $args['id'];?>-click">
                    <input type="radio" name="<?php echo $args['namespace'];?>[extended_widget_opts][slidein][open_trigger]" id="extended_widget_opts-<?php echo $args['id'];?>-click" value="click" <?php echo ( 'click' == $open_trigger ) ? 'checked="checked"' : '';?> /><?php _e( 'onClick', 'widget-options' );?>
                </label>
                <label class="widgetopts-img-box widgetopts-img-box-s <?php echo ( 'hover' == $open_trigger ) ? 'widgetopts-img-box-c' : '';?>" for="extended_widget_opts-<?php echo $args['id'];?>-hover">
                    <input type="radio" name="<?php echo $args['namespace'];?>[extended_widget_opts][slidein][open_trigger]" id="extended_widget_opts-<?php echo $args['id'];?>-hover" value="hover" <?php echo ( 'hover' == $open_trigger ) ? 'checked="checked"' : '';?> /><?php _e( 'MouseOver', 'widget-options' );?>
                </label>
            </li>
            <li class="extended_widget_opts-txt">
                <p><strong><?php _e( 'Auto Open', 'widget-options' );?></strong></p>
                <label class="widgetopts-img-box widgetopts-img-box-s <?php echo ( 'none' == $open ) ? 'widgetopts-img-box-c' : '';?>" for="extended_widget_opts-<?php echo $args['id'];?>-none">
                    <input type="radio" name="<?php echo $args['namespace'];?>[extended_widget_opts][slidein][open]" id="extended_widget_opts-<?php echo $args['id'];?>-none" value="none" <?php echo ( 'none' == $open ) ? 'checked="checked"' : '';?> /><?php _e( 'None', 'widget-options' );?>
                </label>
                <label class="widgetopts-img-box widgetopts-img-box-s <?php echo ( 'enter' == $open ) ? 'widgetopts-img-box-c' : '';?>" for="extended_widget_opts-<?php echo $args['id'];?>-enter">
                    <input type="radio" name="<?php echo $args['namespace'];?>[extended_widget_opts][slidein][open]" id="extended_widget_opts-<?php echo $args['id'];?>-enter" value="enter" <?php echo ( 'enter' == $open ) ? 'checked="checked"' : '';?> /><?php _e( 'onLoad', 'widget-options' );?>
                </label>
                <label class="widgetopts-img-box widgetopts-img-box-s <?php echo ( 'exit' == $open ) ? 'widgetopts-img-box-c' : '';?>" for="extended_widget_opts-<?php echo $args['id'];?>-exit">
                    <input type="radio" name="<?php echo $args['namespace'];?>[extended_widget_opts][slidein][open]" id="extended_widget_opts-<?php echo $args['id'];?>-exit" value="exit" <?php echo ( 'exit' == $open ) ? 'checked="checked"' : '';?> /><?php _e( 'Exit Intent', 'widget-options' );?>
                </label>
                <label class="widgetopts-img-box widgetopts-img-box-s <?php echo ( 'scroll' == $open ) ? 'widgetopts-img-box-c' : '';?>" for="extended_widget_opts-<?php echo $args['id'];?>-scroll">
                    <input type="radio" name="<?php echo $args['namespace'];?>[extended_widget_opts][slidein][open]" id="extended_widget_opts-<?php echo $args['id'];?>-scroll" value="scroll" <?php echo ( 'scroll' == $open ) ? 'checked="checked"' : '';?> /><?php _e( 'Scroll', 'widget-options' );?>
                </label>
            </li>
            <li class="extended_widget_opts-txt widgetopts-img-box-s-o" style="<?php echo ( 'scroll' == $open ) ? 'display: block;' : '';?>">
                <p><strong><?php _e( 'On Scroll Options', 'widget-options' );?></strong><br /><small><?php _e( 'Add on page scroll value and select either percentage or pixels.', 'widget-options' );?></small></p>
                <input type="text" size="5" name="<?php echo $args['namespace'];?>[extended_widget_opts][slidein][scroll]" value="<?php echo $scroll;?>" />
                <label class="widgetopts-img-box <?php echo ( 'percent' == $stype ) ? 'widgetopts-img-box-c' : '';?>" for="extended_widget_opts-<?php echo $args['id'];?>-prcnt">
                    <input type="radio" name="<?php echo $args['namespace'];?>[extended_widget_opts][slidein][onScroll]" id="extended_widget_opts-<?php echo $args['id'];?>-prcnt" value="percent" <?php echo ( 'percent' == $stype ) ? 'checked="checked"' : '';?> /><?php _e( '&nbsp;&nbsp;%&nbsp;&nbsp;', 'widget-options' );?>
                </label>
                <label class="widgetopts-img-box <?php echo ( 'px' == $stype ) ? 'widgetopts-img-box-c' : '';?>" for="extended_widget_opts-<?php echo $args['id'];?>-px">
                    <input type="radio" name="<?php echo $args['namespace'];?>[extended_widget_opts][slidein][onScroll]" id="extended_widget_opts-<?php echo $args['id'];?>-px" value="px" <?php echo ( 'px' == $stype ) ? 'checked="checked"' : '';?> /><?php _e( '&nbsp;px&nbsp;', 'widget-options' );?>
                </label><br />
            </li>
            <li class="extended_widget_opts-txt">
                <p><strong><?php _e( 'Auto Open Trigger', 'widget-options' );?></strong></p>
                <label class="widgetopts-img-box <?php echo ( 'once' == $trigger ) ? 'widgetopts-img-box-c' : '';?>" for="extended_widget_opts-<?php echo $args['id'];?>-once">
                    <input type="radio" name="<?php echo $args['namespace'];?>[extended_widget_opts][slidein][trigger]" id="extended_widget_opts-<?php echo $args['id'];?>-once" value="once" <?php echo ( 'once' == $trigger ) ? 'checked="checked"' : '';?> /><?php _e( 'Once', 'widget-options' );?>
                </label>
                <label class="widgetopts-img-box <?php echo ( 'always' == $trigger ) ? 'widgetopts-img-box-c' : '';?>" for="extended_widget_opts-<?php echo $args['id'];?>-always">
                    <input type="radio" name="<?php echo $args['namespace'];?>[extended_widget_opts][slidein][trigger]" id="extended_widget_opts-<?php echo $args['id'];?>-always" value="always" <?php echo ( 'always' == $trigger ) ? 'checked="checked"' : '';?> /><?php _e( 'Always', 'widget-options' );?>
                </label>
            </li>
            <li>
                <p><strong><?php _e( 'Opener Label', 'widget-options' );?></strong></p>
                <table class="form-table">
                    <tbody>
                        <tr valign="top">
                            <td scope="row"><label for="extended_widget_opts-<?php echo $args['id'];?>-caret"><?php _e( 'Hide Caret:', 'widget-options' );?></label></td>
                            <td><input type="checkbox" id="extended_widget_opts-<?php echo $args['id'];?>-caret" name="<?php echo $args['namespace'];?>[extended_widget_opts][slidein][caret]" value="1" <?php echo ( '1' == $caret ) ? 'checked="checked"' : '';?> /></td>
                        </tr>
                        <tr valign="top">
                            <td scope="row"><?php _e( 'Text:', 'widget-options' );?></td>
                            <td><input type="text" class="widefat" name="<?php echo $args['namespace'];?>[extended_widget_opts][slidein][text]" value="<?php echo $text;?>" /></td>
                        </tr>
                        <tr valign="top">
                            <td scope="row"><?php _e( 'Color:', 'widget-options' );?></td>
                            <td><input type="text" class="widget-opts-color" name="<?php echo $args['namespace'];?>[extended_widget_opts][slidein][color]" value="<?php echo $color;?>" /></td>
                        </tr>
                        <tr valign="top">
                            <td scope="row"><?php _e( 'Background:', 'widget-options' );?></td>
                            <td><input type="text" class="widget-opts-color" name="<?php echo $args['namespace'];?>[extended_widget_opts][slidein][background]" value="<?php echo $background;?>" /></td>
                        </tr>
                        <tr valign="top">
    						<td scope="row" colspan="2"><?php _e( 'Select Icon:', 'widget-options' );?></td>
                        </tr>
                        <tr valign="top">
    						<td colspan="2">
    							<div class="widgetopts-icon-selection">
    								<input type="radio" name="<?php echo $args['namespace'];?>[extended_widget_opts][slidein][icon]" id="widgetopts-dash-<?php echo $args['id'];?>-no" value="no-icon" <?php echo ( 'no-icon' == $icon ) ? 'checked="checked"' : '';?> />
    								<label for="widgetopts-dash-<?php echo $args['id'];?>-no" class="widgetopts-icon-none <?php echo ( 'no-icon' == $icon ) ? 'widgetopts-icon-y' : '';?>"><span><?php _e( 'None','widget-options' );?></span></label>
    								<?php foreach ( $dashicons as $k => $v) { ?>
    									<label for="widgetopts-dash-<?php echo $args['id'];?><?php echo $k;?>" class="<?php echo ( $v == $icon ) ? 'widgetopts-icon-y' : '';?>">
                                            <span class="dashicons <?php echo $v;?>"></span>
                                            <input type="radio" name="<?php echo $args['namespace'];?>[extended_widget_opts][slidein][icon]" id="widgetopts-dash-<?php echo $args['id'];?><?php echo $k;?>" value="<?php echo $v;?>" <?php echo ( $v == $icon ) ? 'checked="checked"' : '';?> />
                                        </label>
    								<?php }?>
    							</div>
    						</td>
    					</tr>
                    </tbody>
                </table>

                <p><strong><?php _e( 'Display', 'widget-options' );?></strong></p>
                <table class="form-table">
                    <tbody>
                        <tr valign="top">
                            <td scope="row"><?php _e( 'Width:', 'widget-options' );?></td>
                            <td><input type="text" size="5" name="<?php echo $args['namespace'];?>[extended_widget_opts][slidein][width]" value="<?php echo $width;?>" /> <?php _e( 'pixels', 'widget-options' );?></td>
                        </tr>
                    </tbody>
                </table>

                <p><strong><?php _e( 'Responsive', 'widget-options' );?></strong></p>
                <table class="form-table">
                    <tbody>
                        <tr valign="top">
                            <td colspan="2">
                                <input type="checkbox" id="extended_widget_opts-<?php echo $args['id'];?>-hide" name="<?php echo $args['namespace'];?>[extended_widget_opts][slidein][hide]" value="1" <?php echo ( '1' == $hide ) ? 'checked="checked"' : '';?> />
                                <label for="extended_widget_opts-<?php echo $args['id'];?>-hide"><?php _e( 'Hide Icon on Desktop & Tablet', 'widget-options' );?></label>
                            </td>
                        </tr>
                        <tr valign="top">
                            <td colspan="2">
                                <input type="checkbox" id="extended_widget_opts-<?php echo $args['id'];?>-hidden" name="<?php echo $args['namespace'];?>[extended_widget_opts][slidein][hidden]" value="1" <?php echo ( '1' == $hidden ) ? 'checked="checked"' : '';?> />
                                <label for="extended_widget_opts-<?php echo $args['id'];?>-hidden"><?php _e( 'Hide Label on Mobile', 'widget-options' );?></label>
                            </td>
                        </tr>
                    </tbody>
                </table>

				<p><strong><?php _e( 'Widget ID', 'widget-options' );?></strong></p>
                <p class="widgetops-sc-opts">
                    <code>#<?php echo $args['id'];?></code>
                </p>
            </li>
        </ul>
        <style>
        .sliding_widgetopts-tab-opts{
            text-align: center;
        }
        .sliding_widgetopts-tab-opts table{
            text-align: left;
        }
        .sliding_widgetopts-tab-opts table td{
            font-size: 13px;
        }
        .widgetopts-img-box img{
            width: 45px;
            border: 3px solid transparent;
            border-radius: 3px;
            background: transparent;
            margin-top: 2px;
        }
        label.widgetopts-img-box-c img{
            border-color: #ddd;
            background-color: #e5e5e5;
        }
        .sliding_widgetopts-tab-opts input[type="radio"]{
            display: none;
        }
        .widgetopts-img-box img:hover{
            background-color: #e5e5e5;
        }
        .extended_widget_opts-txt label{
            border: 2px solid transparent;
            padding: 2px 3px;
            font-size: 13px;
            border-radius: 3px;
            margin-right: 2px;
        }
        .extended_widget_opts-txt label.widgetopts-img-box-c{
            border-color: #ddd;
        }
        .extended_widget_opts-txt label:hover{
            border-color: #e5e5e5;
        }

        .widgetopts-img-box-s-o{
            display: none;
        }

        .sliding_widgetopts-tab-opts .widgetopts-icon-selection{
            height: 190px;
            overflow: scroll;
        }
        .sliding_widgetopts-tab-opts .widgetopts-icon-selection .widgetopts-icon-none{

        }
        .sliding_widgetopts-tab-opts .widgetopts-icon-selection .dashicons{
            font-size: 22px;
            width: 27px;
            height: 28px;
            line-height: 27px;
            border: 1px solid transparent;
        }
        label.widgetopts-icon-none span{
            font-size: 11px;
            border: 1px solid transparent;
            padding: 2px 3px;
            margin-top: 2px;
        }
        .sliding_widgetopts-tab-opts .widgetopts-icon-selection .widgetopts-icon-y span, .sliding_widgetopts-tab-opts .widgetopts-icon-selection .dashicons:hover{
            color: #006799;
        }
        .sliding_widgetopts-tab-opts .widgetopts-icon-selection .widgetopts-icon-y span{
            border-color: #006799;
        }
        </style>
    <?php }
endif;
?>
