<?php
/**
 * Plugin Name: Sliding Widget Options
 * Plugin URI: https://widget-options.com/
 * Description: Turn any widgets to slide-in, modal pop-up and sliding panel to get more user interactions and increase conversions.
 * Version: 1.0.2
 * Author: Widget Options Team
 * Author URI: https://widget-options.com/
 * Text Domain: widgetopts-slidein
 * Domain Path: languages
 *
 * @category Widgets
 * @author Widget Options Team
 * @version 1.0
 */
// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;
if ( ! class_exists( 'SLIDING_WIDGETOPTS' ) ) :
/**
 * Main SLIDING_WIDGETOPTS Class.
 *
 * @since  1.0
 */
final class SLIDING_WIDGETOPTS {
	/**
	 * @var SLIDING_WIDGETOPTS The one true SLIDING_WIDGETOPTS
	 * @since  1.0
	 */
	private static $instance;
	/**
	 * Main SLIDING_WIDGETOPTS Instance.
	 *
	 * Insures that only one instance of SLIDING_WIDGETOPTS exists in memory at any one
	 * time. Also prevents needing to define globals all over the place.
	 *
	 * @since  1.0
	 * @static
	 * @staticvar array $instance
	 * @uses SLIDING_WIDGETOPTS::setup_constants() Setup the constants needed.
	 * @uses SLIDING_WIDGETOPTS::includes() Include the required files.
	 * @uses SLIDING_WIDGETOPTS::load_textdomain() load the language files.
	 * @see SLIDING_WIDGETOPTS_FN()
	 * @return object|SLIDING_WIDGETOPTS The one true SLIDING_WIDGETOPTS
	 */
	public static function instance() {
		if ( ! isset( self::$instance ) && ! ( self::$instance instanceof SLIDING_WIDGETOPTS ) ) {
			self::$instance = new SLIDING_WIDGETOPTS;
			self::$instance->setup_constants();
			// add_action( 'plugins_loaded', array( self::$instance, 'load_textdomain' ) );
			self::$instance->includes();
			// self::$instance->roles         = new WIDGETOPTS_Roles();
		}
		return self::$instance;
	}
	/**
	 * Setup plugin constants.
	 *
	 * @access private
	 * @since 4.1
	 * @return void
	 */
	private function setup_constants() {
		// Plugin version.
		if ( ! defined( 'SLIDING_WIDGETOPTS_PLUGIN_NAME' ) ) {
			define( 'SLIDING_WIDGETOPTS_PLUGIN_NAME', 'Sliding Widget Options' );
		}
		// Plugin version.
		if ( ! defined( 'SLIDING_WIDGETOPTS_PLUGIN_VERSION' ) ) {
			define( 'SLIDING_WIDGETOPTS_PLUGIN_VERSION', '1.0.2' );
		}
		// Plugin Folder Path.
		if ( ! defined( 'SLIDING_WIDGETOPTS_PLUGIN_DIR' ) ) {
			define( 'SLIDING_WIDGETOPTS_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
		}
		// Plugin Folder URL.
		if ( ! defined( 'SLIDING_WIDGETOPTS_PLUGIN_URL' ) ) {
			define( 'SLIDING_WIDGETOPTS_PLUGIN_URL', plugin_dir_url( __FILE__ ) );
		}
		// Plugin Root File.
		if ( ! defined( 'SLIDING_WIDGETOPTS_PLUGIN_FILE' ) ) {
			define( 'SLIDING_WIDGETOPTS_PLUGIN_FILE', __FILE__ );
		}
	}
	/**
	 * Include required files.
	 *
	 * @access private
	 * @since 1.0
	 * @return void
	 */
	private function includes() {
		global $widgetopts_sliding, $pagenow, $widgetopts_sliding_license;

		require_once SLIDING_WIDGETOPTS_PLUGIN_DIR . 'includes/settings/register-settings.php';

		//call admin only resources
		if ( is_admin() ) {
			require_once SLIDING_WIDGETOPTS_PLUGIN_DIR . 'includes/install.php';
			// require_once SLIDING_WIDGETOPTS_PLUGIN_DIR . 'includes/welcome.php';

			if( in_array( $pagenow, array( 'options-general.php' ) ) ){
				require_once SLIDING_WIDGETOPTS_PLUGIN_DIR . 'includes/settings/module-slide.php';
				require_once SLIDING_WIDGETOPTS_PLUGIN_DIR . 'includes/settings/sidebar-license.php';

				if ( ! defined( 'WIDGETOPTS_PLUGIN_NAME' ) || ( defined( 'WIDGETOPTS_PLUGIN_NAME' ) && 'Extended Widget Options' != WIDGETOPTS_PLUGIN_NAME ) ) {
					require_once SLIDING_WIDGETOPTS_PLUGIN_DIR . 'includes/settings/sidebar-purchase-validation.php';
				}
			}

			require_once SLIDING_WIDGETOPTS_PLUGIN_DIR . 'includes/widgets/dashicons.php';
			require_once SLIDING_WIDGETOPTS_PLUGIN_DIR . 'includes/widgets/option-tabs.php';
			// require_once SLIDING_WIDGETOPTS_PLUGIN_DIR . 'includes/admin/metabox.php';
			// require_once SLIDING_WIDGETOPTS_PLUGIN_DIR . 'includes/admin/admin-menus.php';
			// if( defined( 'WIDGETOPTS_PLUGIN_NAME' ) && 'Extended Widget Options' == WIDGETOPTS_PLUGIN_NAME ){
			// 	require_once SLIDING_WIDGETOPTS_PLUGIN_DIR . 'includes/admin/shortcode-column.php';
			// }

			if( class_exists( 'WP_Widget_Options' ) ){
				require_once SLIDING_WIDGETOPTS_PLUGIN_DIR . 'includes/class-edd-license-handler.php';
				// auto updater
				if( class_exists( 'WIDGETOPTS_License' ) ) {
					$widgetopts_sliding_license = new WIDGETOPTS_License( SLIDING_WIDGETOPTS_PLUGIN_FILE, SLIDING_WIDGETOPTS_PLUGIN_NAME, SLIDING_WIDGETOPTS_PLUGIN_VERSION, 'Phpbits Creative Studio' );
				}
			}
		}

		require_once SLIDING_WIDGETOPTS_PLUGIN_DIR . 'includes/scripts.php';
		require_once SLIDING_WIDGETOPTS_PLUGIN_DIR . 'includes/widgets/widget-area.php';
		require_once SLIDING_WIDGETOPTS_PLUGIN_DIR . 'includes/widgets/display.php';

	}
}
endif; // End if class_exists check.
/**
 * The main function for that returns SLIDING_WIDGETOPTS
 *
 * The main function responsible for returning the one true SLIDING_WIDGETOPTS
 * Instance to functions everywhere.
 *
 * Use this function like you would a global variable, except without needing
 * to declare the global.
 *
 * Example: <?php $widgetopts_sliding = SLIDING_WIDGETOPTS(); ?>
 *
 * @since 1.0
 * @return object|SLIDING_WIDGETOPTS The one true SLIDING_WIDGETOPTS Instance.
 */
if( !function_exists( 'SLIDING_WIDGETOPTS_FN' ) ){
	function SLIDING_WIDGETOPTS_FN() {
		return SLIDING_WIDGETOPTS::instance();
	}
	// Get Plugin Running.
	add_action( 'plugins_loaded', 'SLIDING_WIDGETOPTS_FN', apply_filters( 'sliding_widgetopts_priority', 90 ) );
}

//register activation
require_once( dirname( __FILE__ ) . '/includes/welcome.php' );
?>
