<?php
/**
 * Widgets on Menu Settings Module
 * Settings > Widget Options :: Widgets on Menu
 *
 * @copyright   Copyright (c) 2017, Jeffrey Carandang
 * @since       1.0
*/

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Create Card Module for Widgets on Menu Options
 *
 * @since 1.0
 * @return void
 */
if( !function_exists( 'widgetopts_settings_menu' ) ):
	function widgetopts_settings_menu(){
		global $widget_options;
		$option  = ( isset( $widget_options['menu'] ) ) ? $widget_options['menu'] : '';
		$menu 	 = ( isset( $widget_options['settings']['menu'] ) ) ? $widget_options['settings']['menu'] : array(); ?>

		<li class="widgetopts-module-card <?php echo ( $option == 'activate' ) ? 'widgetopts-module-type-enabled' : 'widgetopts-module-type-disabled'; ?>" id="widgetopts-module-card-menu" data-module-id="menu">
			<div class="widgetopts-module-card-content">
				<h2><?php _e( 'Widgets on Menu', 'widget-options-menu' );?></h2>
				<div class="widgetopts-pro-label"><span class="dashicons dashicons-unlock"></span></div>
				<p class="widgetopts-module-desc">
					<?php _e( 'Easily create mega menu navigation by adding widgets as menu contents.', 'widget-options-menu' );?>
				</p>
				<?php //print_r( $visibility );?>
				<div class="widgetopts-module-actions hide-if-no-js">
					<?php if( $option == 'activate' ){ ?>
						<button class="button button-secondary widgetopts-toggle-settings"><?php _e( 'Configure Settings', 'widget-options-menu' );?></button>
						<button class="button button-secondary widgetopts-toggle-activation"><?php _e( 'Disable', 'widget-options-menu' );?></button>
					<?php }else{ ?>
						<button class="button button-secondary widgetopts-toggle-settings"><?php _e( 'Learn More', 'widget-options-menu' );?></button>
						<button class="button button-primary widgetopts-toggle-activation"><?php _e( 'Enable', 'widget-options-menu' );?></button>
					<?php } ?>

				</div>
			</div>

			<?php widgetopts_modal_start( $option ); ?>
				<span class="dashicons widgetopts-dashicons widgetopts-no-top dashicons-menu"></span>
				<h3 class="widgetopts-modal-header"><?php _e( 'Widgets on Menu', 'widget-options-menu' );?></h3>
				<p>
					<?php _e( 'Widgets on Menu is a premium addon that will allow you to add widgets on menu navigation thus giving you flexibility specially when you want to add mega menu navigation. Check <a href="https://widget-options.com/setting-up-wordpress-widgets-on-menu-add-on/?utm_source=widgetsmenudocs" target="_blank">documentation here</a> if you are having issues.', 'widget-options-menu' );?>
				</p>
				<table class="form-table widgetopts-settings-section">
					<tr>
						<th scope="row">
							<label for="widgetopts-menu-relative"><?php _e( 'Remove Relative Position', 'widget-options-menu' );?></label>
						</th>
						<td>
							<input type="checkbox" id="widgetopts-menu-relative" name="menu[static]" <?php echo widgetopts_is_checked( $menu, 'static' ) ?> value="1" />
							<label for="widgetopts-menu-relative"><?php _e( 'Remove Relative Positioning', 'widget-options-menu' );?></label>
							<p class="description">
								<?php _e( 'Remove parent menu relative positioning and change to default(static) to remove widget width conflict.', 'widget-options-menu' );?>
							</p>
						</td>
					</tr>
					<tr>
						<th scope="row">
							<label for="widgetopts-menu-left"><?php _e( 'Fix Sub-menu Position', 'widget-options-menu' );?></label>
						</th>
						<td>
							<input type="checkbox" id="widgetopts-menu-left" name="menu[left]" <?php echo widgetopts_is_checked( $menu, 'left' ) ?> value="1" />
							<label for="widgetopts-menu-left"><?php _e( 'Fix Sub-menu Left Positioning', 'widget-options-menu' );?></label>
							<p class="description">
								<?php _e( 'Check this option if your widget submenu positioning is aligned with the parent menu and not on full width.', 'widget-options-menu' );?>
							</p>
						</td>
					</tr>
					<tr>
						<th scope="row">
							<label for="widgetopts-menu-table"><?php _e( 'Use Tabled Layout', 'widget-options-menu' );?></label>
						</th>
						<td>
							<input type="checkbox" id="widgetopts-menu-table" name="menu[table]" <?php echo widgetopts_is_checked( $menu, 'table' ) ?> value="1" />
							<label for="widgetopts-menu-table"><?php _e( 'Use Table Columns instead Float', 'widget-options-menu' );?></label>
							<p class="description">
								<?php _e( 'Check this option if you want to use table-cell instead of float to get similar vertical heights.', 'widget-options-menu' );?>
							</p>
						</td>
					</tr>
					<tr>
						<th scope="row">
							<label for="widgetopts-menu-hidden"><?php _e( 'Display None First', 'widget-options-menu' );?></label>
						</th>
						<td>
							<input type="checkbox" id="widgetopts-menu-hidden" name="menu[hidden]" <?php echo widgetopts_is_checked( $menu, 'hidden' ) ?> value="1" />
							<label for="widgetopts-menu-hidden"><?php _e( 'Use Display None to Sub-menu onLoad', 'widget-options-menu' );?></label>
							<p class="description">
								<?php _e( 'Hide sub-menu with widgets first to avoid conflict. Check this if you are using Superfish menu or Genesis child theme.', 'widget-options-menu' );?>
							</p>
						</td>
					</tr>
					<tr>
						<th scope="row">
							<label for="widgetopts-menu-block"><?php _e( 'Display Block on Hover', 'widget-options-menu' );?></label>
						</th>
						<td>
							<input type="checkbox" id="widgetopts-menu-block" name="menu[show_on_hover]" <?php echo widgetopts_is_checked( $menu, 'show_on_hover' ) ?> value="1" />
							<label for="widgetopts-menu-block"><?php _e( 'Show Sub-menu on Hover', 'widget-options-menu' );?></label>
							<p class="description">
								<?php _e( 'Use display block on sub-menu when parent was hovered. Check this if you are having conflict and sub-menu is not showing on mouse over.', 'widget-options-menu' );?>
							</p>
						</td>
					</tr>
					<tr>
						<th scope="row">
							<label for="widgetopts-menu-margin"><?php _e( 'Widget Padding', 'widget-options-menu' );?></label>
						</th>
						<td>
							<?php _e( 'Top', 'widget-options-menu' );?>: <input type="text" size="3" id="widgetopts-menu-padding_top" name="menu[padding_top]" value="<?php echo ( isset( $menu['padding_top'] ) ) ? $menu['padding_top'] : ''; ?>" /><small><?php _e( 'px', 'widget-options-menu' );?></small> &nbsp;
							<?php _e( 'Right', 'widget-options-menu' );?>: <input type="text" size="3" id="widgetopts-menu-padding_right" name="menu[padding_right]" value="<?php echo ( isset( $menu['padding_right'] ) ) ? $menu['padding_right'] : ''; ?>" /><small><?php _e( 'px', 'widget-options-menu' );?></small> &nbsp;
							<?php _e( 'Bottom', 'widget-options-menu' );?>: <input type="text" size="3" id="widgetopts-menu-padding_bottom" name="menu[padding_bottom]" value="<?php echo ( isset( $menu['padding_bottom'] ) ) ? $menu['padding_bottom'] : ''; ?>" /><small><?php _e( 'px', 'widget-options-menu' );?></small> &nbsp;
							<?php _e( 'Left', 'widget-options-menu' );?>: <input type="text" size="3" id="widgetopts-menu-padding_left" name="menu[padding_left]" value="<?php echo ( isset( $menu['padding_left'] ) ) ? $menu['padding_left'] : ''; ?>" /><small><?php _e( 'px', 'widget-options-menu' );?></small> &nbsp;
							<p class="description">
								<?php _e( 'Set different widget padding when using as menu instead of default theme paddings. Leave blank for default.', 'widget-options-menu' );?>
							</p>
						</td>
					</tr>
					<tr>
						<th scope="row">
							<label for="widgetopts-menu-margin"><?php _e( 'Widget Margin', 'widget-options-menu' );?></label>
						</th>
						<td>
							<?php _e( 'Top', 'widget-options-menu' );?>: <input type="text" size="3" id="widgetopts-menu-margin_top" name="menu[margin_top]" value="<?php echo ( isset( $menu['margin_top'] ) ) ? $menu['margin_top'] : ''; ?>" /><small><?php _e( 'px', 'widget-options-menu' );?></small> &nbsp;
							<?php _e( 'Bottom', 'widget-options-menu' );?>: <input type="text" size="3" id="widgetopts-menu-margin_bottom" name="menu[margin_bottom]" value="<?php echo ( isset( $menu['margin_bottom'] ) ) ? $menu['margin_bottom'] : ''; ?>" /><small><?php _e( 'px', 'widget-options-menu' );?></small> &nbsp;
							<p class="description">
								<?php _e( 'Set different widget margins when using as menu instead of default theme margins. Leave blank for default.', 'widget-options-menu' );?>
							</p>
						</td>
					</tr>
					<tr>
						<th scope="row">
							<label for="widgetopts-menu-toRelative"><?php _e( 'Position to Relative', 'widget-options-menu' );?></label>
						</th>
						<td>
							<input type="text" class="widefat" id="widgetopts-menu-toRelative" name="menu[toRelative]" value="<?php echo ( isset( $menu['toRelative'] ) ) ? $menu['toRelative'] : ''; ?>" />
							<p class="description">
								<?php _e( 'Add comma separate IDs or classes that you want to change the position to relative, for some positioning fixes such as header.', 'widget-options-menu' );?>
							</p>
						</td>
					</tr>
				</table>
			<?php widgetopts_modal_end( $option ); ?>

		</li>
	    <?php
	}
	add_action( 'widgetopts_module_cards', 'widgetopts_settings_menu', 200 );
endif;
?>
