<?php
/*
 * Create Welcome Screen
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if( !class_exists( 'PHPBITS_extendedWidgetsMenuWelcomeScreen' ) ){
	class PHPBITS_extendedWidgetsMenuWelcomeScreen{

		/*
		 * For easier overriding we declared the keys
		 * here as well as our tabs array which is populated
		 * when registering settings
		 */

		private $textdomain	= 'widget-options-menu';

		public function __construct() {
			if ( is_admin() ) {
				add_action( 'admin_enqueue_scripts', array($this, 'enqueue' ) );
				add_action( 'admin_menu', array($this, 'screen_page' ) );
				add_action( 'activated_plugin', array($this, 'redirect' ) );
				add_action( 'admin_head', array($this, 'remove_menu' ) );
			}
		}

		function enqueue(){
			if ( !isset( $_GET['page'] ) || 'extended-widget-opts-menu-getting-started' != $_GET['page'] )
			return;

			wp_enqueue_style( 'extended-widget-opts-menu-welcome', plugins_url( '../assets/css/welcome.css' , dirname(__FILE__) ) , array(), null );
		}

		function screen_page(){
			add_dashboard_page(
				__( 'Getting started with Widgets on Menu Add-on', $this->textdomain ),
				__( 'Getting started with Widgets on Menu Add-on', $this->textdomain ),
				apply_filters( 'widgetopts_menu_welcome_cap', 'manage_options' ),
				'extended-widget-opts-menu-getting-started',
				array( $this, 'welcome_content' )
			);
		}

		function welcome_head(){
			$selected = isset( $_GET['page'] ) ? $_GET['page'] : 'extended-widget-opts-menu-getting-started';
			?>
			<h1><?php _e( 'Welcome to Widgets on Menu Add-on', $this->textdomain ); ?></h1>
			<div class="about-text">
				<?php _e( 'Congratulations for extending your WordPress widgets! You can now use your widgets on your navigation menu and will be able to create mega menu easily.', $this->textdomain ); ?>
			</div>
			<div class="widgetopts-badge">
				<span class="widgetopts-mascot"></span>
			</div>
			<h2 class="nav-tab-wrapper">
				<a class="nav-tab <?php echo $selected == 'extended-widget-opts-menu-getting-started' ? 'nav-tab-active' : ''; ?>" href="<?php echo esc_url( admin_url( add_query_arg( array( 'page' => 'extended-widget-opts-menu-getting-started' ), 'index.php' ) ) ); ?>">
					<?php _e( 'Getting Started', $this->textdomain ); ?>
				</a>
			</h2>
			<?php
		}

		function welcome_content(){ ?>
			<div class="wrap about-wrap widgetopts-about-wrap">
				<?php $this->welcome_head(); ?>
				<p class="about-description">
					<?php _e( 'Use the tips and instructions below to get started, then you will be up and running in no time. ', $this->textdomain ); ?>
				</p>

				<div class="feature-section two-col">
					<div class="col">
						<h3><?php _e( 'Extend Widgets on Menu Easily!' , $this->textdomain ); ?></h3>
						<p><?php printf( __( 'Use any of your WordPress widgets easily on your navigation menus. Follow the plugin walkthrough video on the right and learn how to integrate your widgets on menus at ease.', $this->textdomain ), esc_url( admin_url('widgets.php') ) ); ?>
					</div>
					<div class="col">
						<div class="feature-video">
							<iframe width="495" height="278" src="https://player.vimeo.com/video/198622500" frameborder="0" allowfullscreen></iframe>
						</div>
					</div>
				</div>

				<div class="feature-section two-col">
					<h3><?php _e( 'Plugin Features', $this->textdomain ); ?></h3>
					<p><?php _e( 'Widgets on Menu Add-on is both easy and extremely powerful on creating a mega menu. We have tons of helpful features that will let you fully manage your widgets and extend functionalities.', $this->textdomain ); ?></p>
					<p><a href="http://widget-options.com/features/" target="_blank" class="widgetopts-features-button button button-primary"><?php _e( 'See all Features', $this->textdomain ); ?></a></p>
				</div>
			</div>
		<?php }

		function redirect($plugin){
			if($plugin=='widget-options-menu-addon/plugin.php') {
				wp_redirect(admin_url('index.php?page=extended-widget-opts-menu-getting-started'));
				die();
			}
		}
		function remove_menu(){
		    remove_submenu_page( 'index.php', 'extended-widget-opts-menu-getting-started' );
		}
	}

	new PHPBITS_extendedWidgetsMenuWelcomeScreen();
}
?>
