<?php
/**
 * Plugin Name: Widgets on Menu Addon
 * Plugin URI: https://widget-options.com/
 * Description: Extends widget display and functionalities to your navigation menu.
 * Version: 1.0.1
 * Author: Phpbits Creative Studio
 * Author URI: https://phpbits.net/
 * Text Domain: widget-options-menu
 * Domain Path: languages
 *
 * @category Widgets
 * @author Jeffrey Carandang
 * @version 1.0
 */
// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;
if ( ! class_exists( 'WP_Widget_Options_Menu' ) ) :
/**
 * Main WP_Widget_Options_Menu Class.
 *
 * @since  3.2
 */
final class WP_Widget_Options_Menu {
	/**
	 * @var WP_Widget_Options_Menu The one true WP_Widget_Options_Menu
	 * @since  1.0
	 */
	private static $instance;
	/**
	 * Main WP_Widget_Options_Menu Instance.
	 *
	 * Insures that only one instance of WP_Widget_Options_Menu exists in memory at any one
	 * time. Also prevents needing to define globals all over the place.
	 *
	 * @since  3.2
	 * @static
	 * @staticvar array $instance
	 * @uses WP_Widget_Options_Menu::setup_constants() Setup the constants needed.
	 * @uses WP_Widget_Options_Menu::includes() Include the required files.
	 * @uses WP_Widget_Options_Menu::load_textdomain() load the language files.
	 * @see WIDGETOPTS_MENU()
	 * @return object|WP_Widget_Options_Menu The one true WP_Widget_Options_Menu
	 */
	public static function instance() {
		if ( ! isset( self::$instance ) && ! ( self::$instance instanceof WP_Widget_Options_Menu ) ) {
			self::$instance = new WP_Widget_Options_Menu;
			self::$instance->setup_constants();
			// add_action( 'plugins_loaded', array( self::$instance, 'load_textdomain' ) );
			self::$instance->includes();
			// self::$instance->roles         = new WIDGETOPTS_Roles();
		}
		return self::$instance;
	}
	/**
	 * Setup plugin constants.
	 *
	 * @access private
	 * @since 4.1
	 * @return void
	 */
	private function setup_constants() {
		// Plugin version.
		if ( ! defined( 'WIDGETOPTS_MENU_PLUGIN_NAME' ) ) {
			define( 'WIDGETOPTS_MENU_PLUGIN_NAME', 'Widgets on Menu Addon' );
		}
		// Plugin version.
		if ( ! defined( 'WIDGETOPTS_MENU_VERSION' ) ) {
			define( 'WIDGETOPTS_MENU_VERSION', '1.0.1' );
		}
		// Plugin Folder Path.
		if ( ! defined( 'WIDGETOPTS_MENU_PLUGIN_DIR' ) ) {
			define( 'WIDGETOPTS_MENU_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
		}
		// Plugin Folder URL.
		if ( ! defined( 'WIDGETOPTS_MENU_PLUGIN_URL' ) ) {
			define( 'WIDGETOPTS_MENU_PLUGIN_URL', plugin_dir_url( __FILE__ ) );
		}
		// Plugin Root File.
		if ( ! defined( 'WIDGETOPTS_MENU_PLUGIN_FILE' ) ) {
			define( 'WIDGETOPTS_MENU_PLUGIN_FILE', __FILE__ );
		}
	}
	/**
	 * Include required files.
	 *
	 * @access private
	 * @since 1.0
	 * @return void
	 */
	private function includes() {
		global $widget_options, $widget_options_menu, $pagenow, $widgetopts_menu_license;

		require_once WIDGETOPTS_MENU_PLUGIN_DIR . 'includes/admin/settings/register-settings.php';

		//call admin only resources
		if ( is_admin() ) {
			require_once WIDGETOPTS_MENU_PLUGIN_DIR . 'includes/install.php';
			// require_once WIDGETOPTS_MENU_PLUGIN_DIR . 'includes/admin/welcome.php';

			if( in_array( $pagenow, array( 'options-general.php' ) ) ){
				require_once WIDGETOPTS_MENU_PLUGIN_DIR . 'includes/admin/settings/modules/menu.php';
				require_once WIDGETOPTS_MENU_PLUGIN_DIR . 'includes/admin/settings/modules/sidebar-license.php';
			}

			if( isset( $widget_options['menu'] ) && 'activate' == $widget_options['menu'] ){
				require_once WIDGETOPTS_MENU_PLUGIN_DIR . 'includes/admin-scripts.php';
				require_once WIDGETOPTS_MENU_PLUGIN_DIR . 'includes/admin/menu/metabox.php';
				require_once WIDGETOPTS_MENU_PLUGIN_DIR . 'includes/admin/menu/update-functions.php';
				require_once WIDGETOPTS_MENU_PLUGIN_DIR . 'includes/admin/transient.php';
			}

			require_once WIDGETOPTS_MENU_PLUGIN_DIR . 'includes/admin/settings/plugins_loaded.php';

			if( class_exists( 'WP_Widget_Options' ) ){
				require_once WIDGETOPTS_MENU_PLUGIN_DIR . 'includes/class-edd-license-handler.php';
				// auto updater
				if( class_exists( 'WIDGETOPTS_License' ) ) {
					$widgetopts_menu_license = new WIDGETOPTS_License( WIDGETOPTS_MENU_PLUGIN_FILE, WIDGETOPTS_MENU_PLUGIN_NAME, WIDGETOPTS_MENU_VERSION, 'Phpbits Creative Studio' );
				}
			}
		}

		require_once WIDGETOPTS_MENU_PLUGIN_DIR . 'includes/admin/widgets/register-sidebar.php';
		// require_once WIDGETOPTS_MENU_PLUGIN_DIR . 'includes/shortcodes.php';
		// require_once WIDGETOPTS_MENU_PLUGIN_DIR . 'includes/admin/widgets/extras.php';
		require_once WIDGETOPTS_MENU_PLUGIN_DIR . 'includes/display.php';
		require_once WIDGETOPTS_MENU_PLUGIN_DIR . 'includes/footer.php';

	}
}
endif; // End if class_exists check.
/**
 * The main function for that returns WP_Widget_Options_Menu
 *
 * The main function responsible for returning the one true WP_Widget_Options_Menu
 * Instance to functions everywhere.
 *
 * Use this function like you would a global variable, except without needing
 * to declare the global.
 *
 * Example: <?php $widgetopts = WP_Widget_Options_Menu(); ?>
 *
 * @since 3.2
 * @return object|WP_Widget_Options_Menu The one true WP_Widget_Options_Menu Instance.
 */
if( !function_exists( 'WIDGETOPTS_MENU' ) ){
	function WIDGETOPTS_MENU() {
		return WP_Widget_Options_Menu::instance();
	}
	// Get Plugin Running.
	add_action( 'plugins_loaded', 'WIDGETOPTS_MENU', apply_filters( 'widgetopts_menu_priority', 90 ) );
}

//register activation
require_once( dirname( __FILE__ ) . '/includes/admin/welcome.php' );
?>
